/*============================================================================
Understanding Labor Market Demand in Real Time in Argentina and Uruguay
Reproducibility package - Appendix
==============================================================================*/

**Appendix 1: : Using job vacancy postings as a leading indicator of labor market health

*Table 15: The relationship between job postings and the unemployment and employment rates in Argentina and Uruguay, 2020-23

use "$data\cleaned\seriesMC_ARG.dta", clear 

reg  d_td L.d_td dln_i_llamados 
outreg2 using "$output\annex\tables\table15.xls", replace
reg  d_te L.d_te dln_i_llamados 
outreg2 using "$output\annex\tables\table15.xls", append
reg  dln_i_td L.dln_i_td L2.dln_maillamados
outreg2 using "$output\annex\tables\table15.xls", append
reg  dln_i_te L.dln_i_te L2.dln_maillamados 
outreg2 using "$output\annex\tables\table15.xls", append

use "$data\cleaned\seriesMC_URY.dta", clear 

reg  d_td L.d_td dln_i_llamados 
outreg2 using "$output\annex\tables\table15.xls", append
reg  d_te L.d_te dln_i_llamados 
outreg2 using "$output\annex\tables\table15.xls", append
reg  dln_i_td L.dln_i_td L2.dln_maillamados
outreg2 using "$output\annex\tables\table15.xls", append
reg  dln_i_te L.dln_i_te L2.dln_maillamados 
outreg2 using "$output\annex\tables\table15.xls", append

erase "$output\annex\tables\table15.txt"

**Appendix 5: Correlations of skill requirements including skill subcategories categories and specific occupations, 2020-23

*Table 17: Correlations of skill requirements including detailed digital skill categories, 2020-23

local ctrs = "ARG URY"

local cell = 3

foreach ctr of local ctrs {

	use "$data\cleaned/postings&skills`ctr'out_tax.dta", clear 
	
	cap drop if check == 2
	
	* only postings
	keep if num_posting==1
	* excluding job postings with missing firm identifiers
	drop if missing(company_id)
	* count postings by firm
	bysort company_id: egen post_count = total(num_posting)
	* keep firms with at least 10 postings
	drop if post_count < 10

	pwcorr posting_cognitive_tot posting_digital1 posting_digital2 posting_digital3 posting_social_tot posting_manual_tot posting_tech_tot 
	
	mat tab17 = r(C)
	
	drop _all 
	
	svmat tab17
	
	export excel using "$output\annex\tables\tables.xlsx", sheet("tab17", modify) cell("C`cell'")
	
	local cell = `cell' + 8

}

*Table 18: Correlations of skill requirements for Software Developers, 2020-23

local ctrs = "ARG URY"

foreach ctr of local ctrs {

	use "$data\cleaned\postings&skills`ctr'out_tax.dta", clear
	
	cap drop if check == 2 

	* only postings
	keep if num_posting==1
	* excluding job postings with missing firm identifiers
	drop if missing(company_id)
	* count postings by firm
	bysort company_id: egen post_count = total(num_posting)
	* keep firms with at least 10 postings
	drop if post_count < 10

	* Skills categories and cognitive skills subcategories
	pwcorr posting_cognitive1 posting_cognitive2 posting_cognitive3 posting_cognitive4 posting_cognitive5 posting_cognitive6 posting_cognitive7 posting_cognitive8 posting_cognitive9 posting_cognitive10 posting_cognitive11 posting_digital_tot posting_social_tot posting_tech_tot  if isco_08_4 == "2512"
	
	mat fig18_1_`ctr' = r(C)
	
	*Skills categories and digital skills subcategories
	pwcorr posting_cognitive_tot posting_digital1 posting_digital2 posting_digital3 posting_social_tot posting_tech_tot  if isco_08_4 == "2512"
	
	mat fig18_2_`ctr' = r(C)
	
	*Skills categories and social skills subcategories
	pwcorr posting_cognitive_tot posting_digital_tot posting_social1 posting_social2 posting_social3 posting_social4 posting_social5 posting_social6 posting_social7 posting_social8 posting_tech_tot  if isco_08_4 == "2512"
	
	mat fig18_3_`ctr' = r(C)
	
}

drop _all 

svmat fig18_1_ARG
svmat fig18_2_ARG
svmat fig18_3_ARG

gen blank1 = . 
gen blank2 = . 
gen blank3 = . 
gen blank4 = . 

order blank1 blank2, after(fig18_1_ARG14)
order blank3 blank4, after(fig18_2_ARG6)

export excel using "$output\annex\tables\tables.xlsx", sheet("tab18", modify) cell("C3")

drop _all 

svmat fig18_1_URY
svmat fig18_2_URY
svmat fig18_3_URY

gen blank1 = . 
gen blank2 = . 
gen blank3 = . 
gen blank4 = . 

order blank1 blank2, after(fig18_1_URY14)
order blank3 blank4, after(fig18_2_URY6)

export excel using "$output\annex\tables\tables.xlsx", sheet("tab18", modify) cell("C18")

*Table 19: Correlations of skill requirements for Administrative and Executive Secretary, 2020-23

foreach ctr of local ctrs {
	
	use "$data\cleaned\postings&skills`ctr'out_tax.dta", clear
	
	cap drop if check == 2
	
	* only postings
	keep if num_posting==1
	* excluding job postings with missing firm identifiers
	drop if missing(company_id)
	* count postings by firm
	bysort company_id: egen post_count = total(num_posting)
	* keep firms with at least 10 postings
	drop if post_count < 10
	
	* Skills categories and cognitive skills subcategories
	pwcorr posting_cognitive1 posting_cognitive2 posting_cognitive3 posting_cognitive4 posting_cognitive5 posting_cognitive6 posting_cognitive7 posting_cognitive8 posting_cognitive9 posting_cognitive10 posting_cognitive11 posting_digital_tot posting_social_tot posting_tech_tot  if isco_08_4 == "3343"
	
	mat fig19_1_`ctr' = r(C)
	
	*Skills categories and digital skills subcategories
	pwcorr posting_cognitive_tot posting_digital1 posting_digital2 posting_digital3 posting_social_tot posting_tech_tot  if isco_08_4 == "3343"
	
	mat fig19_2_`ctr' = r(C)
	
	*Skills categories and social skills subcategories
	pwcorr posting_cognitive_tot posting_digital_tot posting_social1 posting_social2 posting_social3 posting_social4 posting_social5 posting_social6 posting_social7 posting_social8 posting_tech_tot  if isco_08_4 == "3343"
	
	mat fig19_3_`ctr' = r(C)
	
}

drop _all 

svmat fig19_1_ARG
svmat fig19_2_ARG
svmat fig19_3_ARG

gen blank1 = . 
gen blank2 = . 
gen blank3 = . 
gen blank4 = . 

order blank1 blank2, after(fig19_1_ARG14)
order blank3 blank4, after(fig19_2_ARG6)

export excel using "$output\annex\tables\tables.xlsx", sheet("tab19", modify) cell("C3")

drop _all 

svmat fig19_1_URY
svmat fig19_2_URY
svmat fig19_3_URY

gen blank1 = . 
gen blank2 = . 
gen blank3 = . 
gen blank4 = . 

order blank1 blank2, after(fig19_1_URY14)
order blank3 blank4, after(fig19_2_URY6)

export excel using "$output\annex\tables\tables.xlsx", sheet("tab19", modify) cell("C18")