/*============================================================================
Understanding Labor Market Demand in Real Time in Argentina and Uruguay
Reproducibility package - Cleaning 
==============================================================================*/

*1) Utilization-adjusted Human Capital Index (selected countries)

clear all

import excel "$data\raw\uhci_dataappendix_sep2020.xlsx", sheet("DataAppendix_UHCI") firstrow 

keep Countryname Countrycode Gender HCI UHCIbasic

keep if inlist(Countrycode, "POL", "USA", "KOR", "URY", "CHL", "MYS", "ARG") 

gsort Gender -UHCIbasic 

save "$data\cleaned\uhci.dta", replace 

*2) Argentina - Postings 

clear all 

* ------------------------------------------------- use postings dataset 
import delimited "$data\raw\ARG_postings.csv", bindquote(strict)

*-----------------------------------------------------------------------
*	data cleaning and transformation
*-----------------------------------------------------------------------

g controlq = _n
 
*** vars set up

* destring vars
foreach varstring of varlist employment_type company_is_staffing {
	encode `varstring', generate(`varstring'2)
}

* recode vars

recode remote_type (0 = .), gen(remote_type2)
la define remote_type2 1 "remote" 2 "not remote" 3 "hybrid"
la values remote_type2 remote_type2

* generate vars

*- market

g market_name_cod = .
	replace market_name_cod = 1 if market_name == "Buenos Aires (ARG)"
	replace market_name_cod = 2 if market_name == "Catamarca (ARG)"
	replace market_name_cod = 3 if market_name == "Chaco (ARG)"
	replace market_name_cod = 4 if market_name == "Chubut (ARG)"
	replace market_name_cod = 5 if market_name == "Ciudad de Buenos Aires (ARG)"
	replace market_name_cod = 6 if market_name == "Corrientes (ARG)"
	replace market_name_cod = 7 if market_name == "Córdoba (ARG)"
	replace market_name_cod = 8 if market_name == "Entre Ríos (ARG)"
	replace market_name_cod = 9 if market_name == "Formosa (ARG)"
	replace market_name_cod = 10 if market_name == "Jujuy (ARG)"
	replace market_name_cod = 11 if market_name == "La Pampa (ARG)"
	replace market_name_cod = 12 if market_name == "La Rioja (ARG)"
	replace market_name_cod = 13 if market_name == "Mendoza	(ARG)"
	replace market_name_cod = 14 if market_name == "Misiones (ARG)"
	replace market_name_cod = 15 if market_name == "Neuquén (ARG)"
	replace market_name_cod = 16 if market_name == "Río negro (ARG)"
	replace market_name_cod = 17 if market_name == "Salta (ARG)"
	replace market_name_cod = 18 if market_name == "San Juan (ARG)"
	replace market_name_cod = 19 if market_name == "San Luis (ARG)"
	replace market_name_cod = 20 if market_name == "Santa Cruz (ARG)"
	replace market_name_cod = 21 if market_name == "Santa Fe (ARG)"
	replace market_name_cod = 22 if market_name == "Santiago del Estero (ARG)"
	replace market_name_cod = 23 if market_name == "Tierra del Fuego (ARG)"
	replace market_name_cod = 24 if market_name == "Tucumán (ARG)"
	la def market_name_cod 1 "BA" 2 "CA" 3 "CH" 4 "CT" 5 "CABA" 6 "CO" 7 "CB" 8 "ER" 9 "FO" 10 "JY" 11 "LP" 12 "LR" 13 "MZ" 14 "MI" 15 "NQ" 16 "RN" 17 "SA" 18 "SJ" 19 "SL" 20 "SC" 21 "SF" 22 "SE" 23 "TF" 24 "TU"
	la values market_name_cod  market_name_cod

*- employer identification

g company_name_re = company_name if company_raw!="" 
sort company_name_re
by company_name_re: gen company_n = 1 if _n==1
	replace company_n = . if missing(company_name_re)
g company_id = sum(company_n)
	replace company_id = . if missing(company_name_re)	
*- occupation identification
	replace isco_08_1 = "1" if isco_08_1=="1.0"
	replace isco_08_1 = "2" if isco_08_1=="2.0"
	replace isco_08_1 = "3" if isco_08_1=="3.0"
	replace isco_08_1 = "4" if isco_08_1=="4.0"
	replace isco_08_1 = "5" if isco_08_1=="5.0"
	replace isco_08_1 = "7" if isco_08_1=="7.0"
	replace isco_08_1 = "8" if isco_08_1=="8.0"
	replace isco_08_1 = "9" if isco_08_1=="9.0"
	replace isco_08_1 = "" if isco_08_1=="X"
	destring isco_08_1, replace 
	la define isco_08_1 1 "Managers" 2 "Professionals" 3 "Technicians and associate professionals" 4 "Clerical support workers" 5 "Service and sales workers" 6 "skilled agricultural, forestry and fishing" 7 "Craft and related trades workers" 8 "plant and machine operators and assemblers" 9 "Elementary occupations"
	la values isco_08_1 isco_08_1

*- sector identification
g sector_id = 1 if nace_revision2_1_name!=""

*- language identification
g nonspanish = (language!="es")
	replace nonspanish = . if language==""

*- vacancy dates 
g month = substr(posted,6,2)
g day = substr(posted,9,2)
g year = substr(posted,1,4)
destring month day year, replace
g date = ym(year,month)
	format date %tm
g month_ex = substr(expired,6,2)
g year_ex = substr(expired,1,4)
destring month_ex year_ex, replace
g diff_month = month_ex - month
g diff_year = year_ex - year

*- education listed
g aux  = regexm(isced_levels,"99")
g high = regexm(isced_levels_name,"Bachelor|Doctoral|Master")
g mid = regexm(isced_levels_name,"tertiary|Post-secondary")
g low = regexm(isced_levels_name,"Lower secondary education|Upper secondary education")

g educlisted = . if aux==1
	replace educlisted = 1 if low == 1
	replace educlisted = 2 if mid == 1	
	replace educlisted = 3 if high == 1	
	la define educlisted 1 "lower or upper secondary education" 2 "tertiary or post-secondary non tertiary" 3 "bachelor, doctoral or master"
	la values educlisted educlisted
	drop aux low mid high

* identifying job market to compare with EIL vacancies
* same provinces
	g sample_eil = ((market_name_cod==1) | (market_name_cod==5) | (market_name_cod==7) | (market_name_cod==21) | (market_name_cod==13) | (market_name_cod==24) | (market_name_cod==8) | (market_name_cod==3) | (market_name_cod==10))
* exclusion: public sector
	replace sample_eil=0 if nace_revision2_1=="O"
* exclusion: staffing firms
	replace sample_eil=0 if company_is_staffing=="True"

*** delete variables 100% missing or repeated
drop min_years_experience max_years_experience nuts_2021_1* nuts_2021_2* nation_name isced* market market_name remote_type remote_type_name company company_name company_is_staffing lot* unnamed isco_08_1_name

*-------------------------------------------------- SAVE postings dataset	
save "$data\cleaned\ARG_postingsout.dta", replace
 
*3) Uruguay - Postings 

clear all

import delimited "$data\raw\URY_postings.csv", bindquote(strict)

g year=substr(posted,1,4)
g month = substr(posted,6,2)
g day = substr(posted,9,2)
destring year month day, replace

g date = ym(year,month)
format date %tm

g company_name_re = company_name if company_name!="Unclassified" 

	* company id
sort company_name 
by company_name: gen company_n = 1 if _n==1
	replace company_n = . if missing(company_name_re)
	
g company_id = sum(company_n)
	replace company_id = . if missing(company_name_re)
	
*-------------------------------------Table 5
gen sector=nace_revision2_1
replace sector= "Unclassified" if nace_revision2_1=="" 

gen salario=0
replace salario=1 if salary_to!=.

gen employert_name=0
replace employert_name=1 if company_name!="Unclassified" 
replace employert_name=1 if company_raw!="Uruguay Concursa"

*-------------------------------------------------- postings per company
g uno = 1
sort company_name
by company_name: egen postings_per_comp = count(uno)
sum postings_per_comp if company_id!=.
drop uno

* análisis de duplicados
gen one_aux=1
egen dup=sum(one_aux), by (id)

sort dup

drop if dup>1

save "$data\cleaned\baseUryNueva_completa.dta", replace

import delimited "$data\raw\URY_skills.csv", clear

merge m:1 id using "$data\cleaned\baseUryNueva_completa.dta"

* sample posting
sort id 
by id: gen posting_n = 1 if _n==1

save "$data\cleaned\postingsURY_out.dta", replace

*3.1) Chile - Postings 

clear all 

import delimited "$data\raw\CHL_postings.csv", bindquote(strict)

*-----------------------------------------------------------------------
*	data cleaning and transformation
*-----------------------------------------------------------------------

g controlq = _n
 
*** vars set up

* destring vars
foreach varstring of varlist employment_type company_is_staffing {
	encode `varstring', generate(`varstring'2)
}

* recode vars
	recode remote_type (0 = .), gen(remote_type2)
	la define remote_type2 1 "remote" 2 "not remote" 3 "hybrid"
	la values remote_type2 remote_type2

* generate vars

*- market
ta market_name, m
di in red "34.5 missing values"

g market_name_cod = .
	replace market_name_cod = 1	 if market_name ==	"Antofagasta (CHL)"
	replace market_name_cod = 2	 if market_name ==	"Antártica Chilena (CHL)"
	replace market_name_cod = 3	 if market_name ==	"Arauco (CHL)"
	replace market_name_cod = 4	 if market_name ==	"Arica (CHL)"
	replace market_name_cod = 5	 if market_name ==	"Aysén (CHL)"
	replace market_name_cod = 6	 if market_name ==	"Bío-Bío (CHL)"
	replace market_name_cod = 7	 if market_name ==	"Cachapoal (CHL)"
	replace market_name_cod = 8	 if market_name ==	"Capitán Prat (CHL)"
	replace market_name_cod = 9	 if market_name ==	"Cardenal Caro (CHL)"
	replace market_name_cod = 10 if market_name ==	"Cauquenes (CHL)"
	replace market_name_cod = 11 if market_name ==	"Cautín (CHL)"
	replace market_name_cod = 12 if market_name ==	"Chacabuco (CHL)"
	replace market_name_cod = 13 if market_name ==	"Chañaral (CHL)"
	replace market_name_cod = 14 if market_name ==	"Chiloe (CHL)"
	replace market_name_cod = 15 if market_name ==	"Choapa (CHL)"
	replace market_name_cod = 16 if market_name ==	"Colchagua (CHL)"
	replace market_name_cod = 17 if market_name ==	"Concepción (CHL)"
	replace market_name_cod = 18 if market_name ==	"Copiapó (CHL)"
	replace market_name_cod = 19 if market_name ==	"Cordillera (CHL)"
	replace market_name_cod = 20 if market_name ==	"Coyhaique (CHL)"
	replace market_name_cod = 21 if market_name ==  "Curicó (CHL)"
	replace market_name_cod = 22 if market_name ==	"Diguillín (CHL)"
	replace market_name_cod = 23 if market_name ==	"El Loa (CHL)"
	replace market_name_cod = 24 if market_name ==	"Elqui (CHL)"
	replace market_name_cod = 25 if market_name ==	"General Carrera (CHL)"
	replace market_name_cod = 26 if market_name ==	"Huasco (CHL)"
	replace market_name_cod = 27 if market_name ==	"Iquique (CHL)"
	replace market_name_cod = 28 if market_name ==	"Isla de Pascua (CHL)"
	replace market_name_cod = 29 if market_name ==	"Itata (CHL)"
	replace market_name_cod = 30 if market_name ==  "Limarí (CHL)"
	replace market_name_cod = 31 if market_name ==	"Linares (CHL)"
	replace market_name_cod = 32 if market_name ==	"Llanquihue (CHL)"
	replace market_name_cod = 33 if market_name ==	"Los Andes (CHL)"
	replace market_name_cod = 34 if market_name ==	"Magallanes (CHL)"
	replace market_name_cod = 35 if market_name ==	"Maipo (CHL)"
	replace market_name_cod = 36 if market_name ==	"Malleco (CHL)"
	replace market_name_cod = 37 if market_name ==	"Marga Marga (CHL)"
	replace market_name_cod = 38 if market_name ==	"Melipilla (CHL)"
	replace market_name_cod = 39 if market_name ==	"Osorno (CHL)"
	replace market_name_cod = 40 if market_name ==	"Palena (CHL)"
	replace market_name_cod = 41 if market_name ==	"Parinacota (CHL)"
	replace market_name_cod = 42 if market_name ==	"Petorca (CHL)"
	replace market_name_cod = 43 if market_name ==	"Punilla (CHL)"
	replace market_name_cod = 44 if market_name ==	"Quillota (CHL)"
	replace market_name_cod = 45 if market_name ==	"Ranco (CHL)"
	replace market_name_cod = 46 if market_name ==	"San Antonio (CHL)"
	replace market_name_cod = 47 if market_name ==  "San Felipe (CHL)"
	replace market_name_cod = 48 if market_name ==	"Santiago (CHL)"
	replace market_name_cod = 49 if market_name ==	"Talagante (CHL)"
	replace market_name_cod = 50 if market_name ==	"Talca (CHL)"
	replace market_name_cod = 51 if market_name ==	"Tamarugal (CHL)"
	replace market_name_cod = 52 if market_name ==	"Tierra del Fuego (CHL)"
	replace market_name_cod = 53 if market_name ==	"Tocopilla (CHL)"
	replace market_name_cod = 54 if market_name ==	"Ultima Esperanza (CHL)"
	replace market_name_cod = 55 if market_name ==	"Valdivia (CHL)"
	replace market_name_cod = 56 if market_name ==	"Valparaíso (CHL)"

	la def market_name_cod 1 "ANF" 2 "ANT" 3 "ARA" 4 "ARI" 5 "AYS" 6 "BB" 7 "CAC" 8 "CP" 9 "CC" 10 "CAU" 11 "CT" 12 "CHB" 13 "CNR" 14 "CHI" 15 "CHO" 16 "COL" 17 "CCP" 18 "CPO" 19 "COR" 20 "CXQ" 21 "CUR" 22 "DIG" 23 "TF" 24 "ELL" 25 "GC" 26 "HSO" 27 "IQQ" 28 "IPC" 29 "ITA" 30 "LMR" 31 "LIN" 32 "LIA" 33 "LND" 34 "MAG" 35 "MAI" 36 "MAL" 37 "MRG" 38 "MEL" 39 "ZOS" 40 "PAL" 41 "PAR" 42 "PET" 43 "PUN" 44 "QTA" 45 "RNC" 46 "SAI" 47 "SFP" 48 "SCL" 49 "TLG" 50 "TLX" 51 "TMR" 52 "TDF" 53 "TOQ" 54 "UE" 55 "ZAL" 56 "VAP"
	la values market_name_cod  market_name_cod

*- employer identification
g company_name_re = company_name if company_raw!="" 

sort company_name_re
by company_name_re: gen company_n = 1 if _n==1
	replace company_n = . if missing(company_name_re)
g company_id = sum(company_n)
	replace company_id = . if missing(company_name_re)
	
*- occupation identification
	replace isco_08_1 = "1" if isco_08_1=="1.0"
	replace isco_08_1 = "2" if isco_08_1=="2.0"
	replace isco_08_1 = "3" if isco_08_1=="3.0"
	replace isco_08_1 = "4" if isco_08_1=="4.0"
	replace isco_08_1 = "5" if isco_08_1=="5.0"
	replace isco_08_1 = "7" if isco_08_1=="7.0"
	replace isco_08_1 = "8" if isco_08_1=="8.0"
	replace isco_08_1 = "9" if isco_08_1=="9.0"
	replace isco_08_1 = "" if isco_08_1=="X"
	destring isco_08_1, replace 
	la define isco_08_1 1 "Managers" 2 "Professionals" 3 "Technicians and associate professionals" 4 "Clerical support workers" 5 "Service and sales workers" 6 "Skilled agricultural, forestry and fishing" 7 "Craft and related trades workers" 8 "Plant and machine operators and assemblers" 9 "Elementary occupations"
	la values isco_08_1 isco_08_1

*- sector identification
g sector_id = 1 if nace_revision2_1_name!=""

*- language identification
g nonspanish = (language!="es")
	replace nonspanish = . if language==""

*- vacancy dates 
g month = substr(posted,6,2)
g day = substr(posted,9,2)
g year = substr(posted,1,4)
destring month day year, replace
g date = ym(year,month)
	format date %tm
g month_ex = substr(expired,6,2)
g year_ex = substr(expired,1,4)
destring month_ex year_ex, replace
g diff_month = month_ex - month
g diff_year = year_ex - year

*- education listed
g aux  = regexm(isced_levels,"99")
g high = regexm(isced_levels_name,"Bachelor|Doctoral|Master")
g mid = regexm(isced_levels_name,"tertiary|Post-secondary")
g low = regexm(isced_levels_name,"Lower secondary education|Upper secondary education")

g educlisted = . if aux==1
	replace educlisted = 1 if low == 1
	replace educlisted = 2 if mid == 1	
	replace educlisted = 3 if high == 1	
	la define educlisted 1 "lower or upper secondary education" 2 "tertiary or post-secondary non tertiary" 3 "bachelor, doctoral or master"
	la values educlisted educlisted
	drop aux low mid high

*** delete variables 100% missing or repeated
drop min_years_experience max_years_experience nuts_2021_1* nuts_2021_2* nation_name isced* market market_name remote_type remote_type_name company company_name company_is_staffing lot* unnamed isco_08_1_nam

*-------------------------------------------------- SAVE postings dataset	
 save "$data\cleaned\CHL_postingsout.dta", replace

*4) Argentina and Uruguay - Skills classification 

local ctrs "ARG URY"

foreach ctr of local ctrs {

	clear all 
	
	import delimited using "$data/raw/`ctr'_skills.csv"
	
	duplicates drop skill_id, force
	
	*--------------------------------------------- prepara vars
	ren skill_subcategory_name subcategory
	ren skill_name skill
	g dis_software = (is_software=="True")
	
	*-----------------------------------------------------------------
	* 1 -- clasificacion utilizando keywords taxonomia> keywords.xlsx
	*-----------------------------------------------------------------
	
	**////////////////////////////Cognitive////////////////////////////
	
	* cognitive/ cognitive/ thinking
	g CogCog_thinking = regexm(skill, "Solving|Solution Identification|Problem Analysis|Research|Analy|Thinking|Ideas|Devise Rule|Evaluate|Interpret Rule|Decision|Information Processing|Error recognition|Identify Error|Correcting|Error Recognition|Reviewing|Long-term Vision|Goal Setting|Strategic Alignement|Strategic Planning|Developmental Asimsessment|Digital Humanities|Digital Media Strategy|Digital Preservation|Digital Transformation|Digital Twin|Digital Mockup|Digital Prototyping")
	
	* cognitive/ cognitive/ math
	g  CogCog_math = regexm(skill, "Math|Digital Logic|Statistic|Calculation|Measurement|Calculus|Probability|Algebra|Bayesian|Causal Inference|Geometry|Equations|Sampling|Time Series|Trigonometry")
		
	* cognitive/ writing/ communicaton
	g CogWri_communication = regexm(skill,"Writing|Editing|Reports|Proposals|Message Development|Digital Brand Engagement|Digital Publishing|Digital Imaging|Digital Journalism|Digital Media|Plain Text|Digital Content")
	
	* cognitive/ financial/ financial
	g CogFin_financial = regexm(skill, "Budgeting|Accounting|Financ|Cost|Financial Modelling|Budget Analysis|Profitability Analysis|Accounts Payable|Accounts Receivable|Bookkeeping|Revenue Projections|Payroll Processing|Billing Design|General Ledger|Balance Sheet|Fund Development")
	
	* cognitive/ business systems/systems 
	g CogBusS_systems = regexm(skill, "Systems Development|Systems Integration|Systems Architecture|Business Systems|Business Intelligence|Management Systems|Systems Analysis|Business Management|Business Solutions|Business Operations|Business Process|Business Administration|System Administration|Process Design|Key Performance Indicators|Elliptic Curve Digital Signature Algorithm|Digital Dashboards|Digital Modeling And Fabrication|Scalability Testing")
			
	* cognitive/ business systems/quality assurance & control 
	g CogBusS_qualityac = regexm(skill, "API Testing|Acceptance Testing|Ad Hoc Testing|Agile Testing|Application Security Testing|Back End Testing|Code Testing|Compatibility Testing|Compliance Testing|Concept Testing|Conformance Testing|Data-Centric Testing|Data-Driven Testing|Database Testing|Dev Testing|Development Testing|Distributed Testing|Dynamic Application Security Testing (DAST)|External Testing|Factory And Site Acceptance Testing|Integration Testing|Laboratory Testing|Lean Functional Testing|Load Testing|Maintenance Testing|Mobile Application Testing|Multivariate Testing|Network Testing|Non-Functional Testing|Open Source Security Testing Methodology|Package Testing|Penetration Testing|Performance Testing|Scenario Testing|Security Testing|Shift-Left Testing|Smoke Testing|SOA|Service-Oriented Architecture Testing|Static Application Security Testing|SAST|Unit Testing|Usability Testing|User Acceptance Testing|UAT|User Interface Testing|Web Accessibility Testing|Web Application Penetration Testing|Web Testing|Six Sigma|KPI|Six Sigma|Digital Assurance|Progress Reporting")
	
	* cognitive/business analysis/business_analysis
	g CogBusA_busanalysis = regexm(skill, "Business Strategy|Business Development|Business Analysis|Performance Analysis|Root Cause Analysis|Business Case Analysis|Competitive Analysis|Market Analysis|Variance Analysis|Failure Analysis|Threat Analysis|Risk Mitigation|Risk and Mitigation Analysis|Sales Trend Analysis|Credit Analysis|Cash Flow Analysis|Benefits Analysis|Organizational Analysis|Sales Analysis|Pricing Analysis|Industry Analysis|Strategic Analysis|Policy Analysis|Business Planning|Scenario Planning|Contingency Planning|Theory of Change Development|Budget Development|Commercial Development|Corporate Development|Product Roadmap Development|Proposal Development|Real Estate Development|Regional Development|Renewable Energy Development|Technology Strategy Development|Category Development|Collection Development|Community Development|Architectural Development|Collateral Development|Digital Strategy Development|Digital Experience Strategy|Digital Consulting")
		
	* cognitive /project management/project management 
	g CogProMan_proman = regexm(skill, "Project Management|Troubleshooting|Quality Assurance and Control|Quality Management|Project Planning and Development Skills|Case Management|Process Improvement|Operations Management|Strategic Planning|Program Management|Change Management|Program Development|Development Support|Early Phase Development|Digital Productions")
	
	* cognitive /data analysis/data analysis
	g CogDA_dataanalysis=regexm(skill, "Data Analy|Data Engineering|Data Modeling|Assessment Data|Data Validation|Data Reports|Data Operations|Abstract Data Types|App Data|Application Data|Cluster Analysis|Automatic Identification And Data Capture|Bibliographic Databases|Binary Data|Categorical Data|Change Data Capture|CDC|Climate Data Exchange|CDX|Clinical Data Interchange Standards Consortium|Clinical Data Review|Command And Data Handling|Data Abstraction|Data Annotations|Data Classification|Data Comparison|Data Compilation|Data Compression|Data Conditioning|Data Consistency|Data Corruption|Data Cube|Data Curation|Data Definition Language|Data Dictionary|Data Intelligence|Data Layers|Data Libraries|Data Link|Data Literacy|Data Localization|Data Policy Development|Data Preprocessing|Data Reduction|Data Redundancy|Data Reference Model|Data Remanence|Data Reporting|Data Selection|Data Strategy|Database Cluster|Database Consistency|Database Schema|Database Theory|Geospatial Databases|Geospatial Datasets|Legal Databases|Material Safety Data Sheet|Non-Relational Data Stores|Reference Data|Transaction Data|Physician Data Query|Data Collection|Data Management|Data Structures|Data Integration|Relational Databases|Data Warehousing|Database Management|Database Administration|Data Transformation|Data Architecture|Data Acquisition|Database Schemas|Data Mapping")
	
	* cognitive /language/language
	g CogLan_language = regexm(skill,"Afrikaans|Albanian|Arabic|Asturian|Azerbaijani|Basque|Belarusian|Bengali|Bilingual|Bulgarian|Catalan|Cebuano|Chinese|Czech|Danish|Dutch|English|Esperanto|Finnish|Foreign Language|French|Galician|German|Greek|Hebrew|Hungarian|Indi|Indonesian|Italian|Japanese|Kurdish|Languages Of Africa|Languages Of Asia|Lituanian|Malay|Norwegian|Polish|Portuguese|Romanian|Russian|Serbian|Slovak|Slovenian|Spanish|Swedish|Thai|Turkish|Ukranian|Urdu|Vietnamese|Waray|Welsh")
			
	* cognitive /adaptability/adaptability	
	g CogAdap_adaptability = regexm(skill,"Adaptability|Openness|Flexibility")
		
	
	egen cognitive = rsum(Cog*)
		* solving overlaps
		foreach var of varlist CogCog_thinking CogBusS_systems {
			replace `var' = 0 if skill=="Measurement Systems Analysis"
		} 
		
	
	* correcting classification error, word "cost" 
		replace CogFin_financial = 0 if skill =="Costume Design" 
	* correcting classification error, word "analysis, research" when it is related to accounting and finance
		replace CogCog_thinking = 0 if CogFin_financial == 1 
	* correcting classification error, word "analysis" when it is related to data analysis
		replace CogCog_thinking = 0 if CogDA_dataanalysis == 1
		
	capture drop cognitive
	egen cognitive = rsum(Cog*)

				
	**////////////////////////////Digital////////////////////////////
	
	* digital - basic level: Ability to access and use digital technologies to perform basic tasks
	/* 1. Functional use of digital devices
	2. Online communication via emails
	3. Using software for presentations, basic spreadsheet use
	4. Finding, managing, and storing digital information and content (e.g., social media)
	*/
	
	g Digital_basic = regexm(skill, "Microsoft Word|Microsoft Excel|Microsoft Outlook|Microsoft PowerPoint|Microsoft Office|Microsoft Windows|Microsoft Access|Computer Literacy|Computer Hardware Knowledge|Computer Software Knowledge|Computer Hardware|Software Knowledge|Online Research|Basic Internet Skills|Windows|Webmail|zip|Zip|Apple|Mac OS|Computer Networking|Digital Literacy|Smartphone Operation|Tablets|Web Navigation|Screen Sharing|Screen Capture|Personal Computers|Mobile Phones|Dropbox|Google Drive|OneDrive|Google|Hardware Installation|Computer Installation|Computer Maintenance|Computer Repair|Computer Troubleshooting|Software Installation|Software Maintenance|Software Configuration|End-User Support|IT Support|Help Desk|Service Desk|Information Technology Industry Knowledge|Telecommunications")
	
	* digital - intermediate level: Ability to use professional software for analysis, creation, management, and design
	/*1. Using professional software for analytics, accounting, project management
	2. Digital marketing, social media analytics
	3. Web design, graphic design
	*/
	
	g Digital_interm = regexm(skill, "Spreadsheets|Tableau|Digital Painting|Digital Photography|Digital Printing|Digital Recording|Digital Signage|Digital Signal|Digital Single-Lens Reflex Cameras|Digital Sketching|Digital Technology|Digital Video|Digital Video Production|Digital Video Recorder|Digital Visual Interface|Digital Volt-Ohm Meter|Digital-To-Analog Converter|Web Design|Web Site Design|Website Design|Digital Video|Digital Filter|Digital Forensics|Digital Illustration|Digital Image|Digital Integration|Digital Mailroom|Digital Cameras|Digital Currency|Digital Decoupling|Digital Electronics|Video Games|Linux|Network Hardware|Network Configuration|Network Administration|Network Support|Information Systems|Transmission Control Protocol (TCP)|Internet Protocol (IP)|TCP/IP|Wide Area Network (WAN)|Hardware Configuration|Routers|Database Design|Relational Database Management System|RDMS|Data Migration|Database Software|Data Warehouse Processing|Data Conversion|Database Tuning|Relational Database Design|Data Warehouse Development|Data Archiving|MySQL|NoSQL|Data Entry|Database Cloning|Database Cluster|Database Connection|Database Consistency|Database Console Commands|Database Conversion|Database Cursor|Database Development|Database Encryption|Database First|Database Mirroring|Database Modeling|Database Permissions|Database Queries|Database Query Tools|Database Schema|Database Storage Structures|Database Theory|Database Triggers|Database Upgrades|Data Infrastructure|Data Access|Data Administration|Data Cabling|Data Caching|Data Capture|Data Centers|Data Loss Prevention|Data Maintenance|Data Masking|Data Monetization|Data Normalization|Data Partitioning|Data Pipelines|Data Recording|Data Recovery|Data Retention|Data Retrieval|Data Room|Data Scraping|Data Stor|Data Transmissions|Data Transport Utility|Data Vaults|Database Optimization|Database Programming|Data Archives|Data Binding|Data Blending|Data Build Tool|Data Sharing|Data Streaming|Data Synchronization|Data Transfer Object|Data Verification|Data Virtualization|Data Wrangling|Data-Structured Language|Database Activity Monitoring|Database Triggers|Datafeed|Datamodel|Dataportability|Datasheets|Dataspaces|Datawindow|Dirty Data|Data Security Standards|Persistent Data Structure|DOCSIS") 
	
	* digital - advanced level: Ability to perform specialized ICT tasks
	/*1. Computer programming
	2. Cloud computing, network management
	3. Artificial intelligence
	4. Data science, big data analytics
	5. Cyber security
	6. Web development, search engine optimization
	*/
	
	g Digital_advanced = regexm(skill, "Mainframe|System Administration|Programming Language|SQL|Javascript|Adobe|Python|Java|ALGO|.NET|AWS|CRM|Active|ADP|Amazon|Android|Apache|Cloud|Azure|Nextcloud|AMS|Agile|Phone Systems|Box|Web Development|Web Application Development|Digital Converters|Asymmetric Digital Subscriber Line|Counters (Digital)|Digital Architecture|Digital Archiving|Digital Polymerase Chain Reaction|Digital Audio|Digital Elevation Models|Digital Signature|Digital Network Architecture|Integrated Digital Enhanced Networks|Integrated Services Digital Networks|Personal Digital Assistant|Plesiochronous Digital Hierarchy|Single-Pair High-Speed Digital Subscriber Lines|Sony Dynamic Digital Sound|SharePoint Development|Secure Application Development|Agile Model Driven Development|Application Development|Video Game Development|Secure Application Development|Acceptance Test-Driven Development|Agile Model Driven Development|Application Development|Assay Development|Behavioral-Driven Development|Compiler Development|Distributed Development|Expo (Application Development Framework)|Firmware Development|Full Stack Development|IOS Development|Instrument Development|Iterative and Incremental Development|Microservices Development|Microsoft Security Development Lifecycle|Mobile Application Development|Mobile Platform Development|Open Source Development|Oracle Application Development Framework|Oracle Development|Package Development Process|Persona Development|Proof of Concept (POC) Development|REST API Development|Rapid Application Development|Technology Strategy Development|Test-Driven Development (TDD)|Unit Test-Driven Development|Vienna Development Methods|Behavior-Driven Development|Feature-Driven Development|Iterative And Incremental Development|Proof Of Concept|Test-Driven Development|Cyber Security|Network Security|Hardware Security|Application Security|Blockchain Security|CompTIA|Computer Security|Data Security|Digital Security|Endpoint Security|GIAC|IT Security|Information Technology Security|Internet Security|Firmware Security|Messaging Security|Security Technology|Security Token|Logical Security|Microservices Security|Offensive Security Wireless|Sanity Testing|Operational Technology (OT) Security|Multiplexed Transport Layer Security|SSL Security|Virtualization Security|Transport Layer Security|Security Descriptor|Security Devices|Security Content Automation Protocol|eLearnSecurity Junior Penetration Tester (eJPT)|Security Log|Shift Left Security|Session Description Protocol Security Descriptions|Sherwood Applied Business Security Architecture|DigitalOcean|Guidewire Digital|Ethernet Configuration Testing|Application Testing|Testing (NDT)|Electrical Testing Instruments|Computer-Aided Dispatch|Data Visualization|MDM|Database Architecture|Data Integrity|Digital Data|Dynamic Data|Distributed Data Store|Electronic Data Information Source|Electronic Data Interchange|Extended Data Services|General Data Protection Regulation (GDPR)|Guidewire Data|Legal Electronic Data Exchange Standard|Mobile Data|Object-Relational Database|Offsite Data Protection|Open Data Protocol|Oracle Database Appliance|Oracle Database Vault|Packet Data Convergence Protocol|Simple Data|Format|Simple Object Database Access|Source Data|Spatial Data Infrastructures|Standard Test Data Format|Electronic Data Interchange For Administration Commerce And Transport (EDIFACT)|Unstructured Supplementary Service Data|User Datagram Protocol|Data Item Descriptions|Evolution-Data Optimized|Remote Data Capture|Vector Data|Aggregator|Web Scraping|Sensor Fusion|Data Direct Networks|Data Discovery|Data Display Debuggers|Data Distribution Services|Data Domain|Data Driven Instruction|Data Element|Data Encoding|Data Exchange|Data Exploitation|Data Extraction|Data Feed|Data Files|Data Flow Diagram|Data Fusion|Data Governance|Data Grid|Aerospike Database|Connected Data Objects|Datacards|Global Data Synchronization Networks|Data Mining|Predictive Analytics|Predictive Model|Data Manipulation|Data Cleaning|Data Evaluation|A/B Testing|Data Preprocessing|Data Profiling|Data Quality|Data Processing|Data Synthesis|Dataframe|Experimental Data|GPS Data|Geophysical Data|Machine-Generated Data|Market Data|Merging Data|Minimum Data Set|Missing Data|Panel Data|Raw Data|Real Time Data|Real World Data|Seismic Data|Semi-Structured Data|Static Data|Tabular Data|Test Data|Test Data Generation|Test Datasets|Tracking And Data Relay Satellites|Training Datasets|Transaction Data|Unstructured Data|Digital Mapping|Big Data|Data Operations|Very Large Databases|VLDB|Cellular Digital Packet Data|Data Science") 
		replace Digital_advanced = 1 if skill=="C++" | skill == "Data Hiding (Encapsulation)" | skill == "Consensus CDS Project (Biological Databases)" | skill == "Payment Card Industry (PCI) Data Security Standards"
		replace CogCog_thinking = 0 if Digital_advanced == 1
	
	*--- ai
	g ai_a = regexm(skill, "Artificial Intelligence|Machine Learning|Decision Trees|Apache Hadoop|Bayesian Networks|Automation Tools|Neural Networks|Support Vector Machines|SVM|Decision Trees|Supervised Learning|TensorFlow|MapReduce|Splunk|Convolutional Neural Network|CNN|AI ChatBot|AI KIBIT|ANTLR|Apertium|Automatic Speech Recognition|ASR|Automated Testing")
	g ai_b = regexm(skill, "Caffe Deep Learning Framework|Chatbot|Computational Linguistics|Computer Vision|Deep Learning|Deeplearning4j|Distinguo|Google Cloud Machine Learning Platform|Gradient Boosting|H2O software|IBM Watson|Image Processing|Image Recognition|IPSoft Amelia|Ithink|Keras|Latent Dirichlet Allocation|Latent Semantic Analysis|Lexalytics|Lexical Acquisition|Lexical Semantics|Libsvm|Machine Translation|MT|Machine Vision|Madlib|Mahout|Microsoft Cognitive Toolkit|Mlpy")
	g ai_c = regexm(skill, "Modular Audio Recognition Framework|MARF|MoSes|MXNet|Natural Language Processing|Natural Language Toolkit|NLTK|ND4J Software|Nearest Neighbor Algorithm|Object Recognition|Object Tracking|OpenCV|OpenNLP|Pattern Recognition|Pybrain|Random Forests|Recommender Systems|Semantic Driven Subtractive Clustering Method|SDSCM|Semi-Supervised Learning|Sentiment Analysis|Opinion Mining|Sentiment Classification|Speech Recognition|Text Mining|Text to Speech|TTS|Tokenization|Torch|Machine Learning|Unsupervised Learning|Virtual Agents|Vowpal|Wabbit|Word2Vec|Xgboost")
	g AI = (ai_a==1 | ai_b==1 | ai_c==1 | skill=="MLPACK C++ library")
		replace AI = 0 if Digital_interm == 1
		replace Digital_advanced = 1 if AI==1
		drop ai_* AI
	
	
	egen digital = rsum(Digital*)

	* correcting classification using is_software variable
		replace Digital_interm = 1 if digital==0 & dis_software==1
	
	capture drop digital
	egen digital = rsum(Digital*)
		
	* correcting classification error, word "Management" 
	g mgm = regexm(skill, "Management")
		replace Digital_interm = 0 if mgm==1 & (CogBusA_busanalysis==1 | CogProMan_proman==1 | CogBusS_systems==1 |  CogFin_financial==1)
	* correcting classification error, word "Software"
	g software = regexm(skill, "Software")
		replace CogCog_thinking = 0 if software==1 & Digital_interm==1
		replace CogFin_financial = 0 if software==1 & Digital_interm==1
	* correcting classification error related to bus	
		foreach var of varlist CogCog* CogFin_financial CogDA_dataanalysis CogBus* CogProMan_proman CogWri_communication CogLan_language {
		replace `var' = 0 if `var'==1 & Digital_interm == 1
	}
	
			drop mgm software
			
	capture drop digital
	egen digital = rsum(Digital*)
	
	capture drop cognitive
	egen cognitive = rsum(Cog*)

	**////////////////////////////Social////////////////////////////
	
	
	* social/ social/ teamwork
	g SocSoc_teamwork = regexm(skill, "Team|Collaboration|Team Building|Cooperation|Interpersonal|Support Colleagues|Relationship Building|Entrepreneurship|Intrapreneurship|Motivational Skills|Build Relationships|Manages Conflict|Confrontation|Influencing Skills|Peer Support")
			
	* social/ social/ communication
	g SocSoc_communication = regexm(skill, "Communication|Oral Communication|Negotiation|Presentation|Public Speaking|Articulate|Persuasion|Persuade|Listening|Lobby|Teach|Diplomacy|Verbal Communication|Advertise|Entertain|Interact with Others|Distress Signals|Motivational Speaking|Storytelling")
		
		* social/ social/ general
	g SocSoc_general = regexm(skill,"Flexibility|Empathy|Emphathetic|Assertive|Decisiveness|Social Intelligence|Emotional Intelligence|Social Skills|Social Perceptiveness")
		
	* social/ character/Organizational skills 
	g SocChar_orgskills = regexm(skill, "Direction|Control|Planning|Strategic Planning|Organized|Sets Goals|Detail-Oriented|Multitasking|Time Management|Meets Deadlines|Prioritiz|Schedul|Due Diligence|Task Management|Self-Discipline|Self-Sufficiency|Solutions Focused|Stewardship|Success Driven|Working Quickly|Proactivity|Results Focused|Time allocation|Deadlines|Emergency Response|Challenge Driven|Coordinating|Delivery Focused|Executive Presence|Goal-Oriented|Accountability|Professional Responsibility|Digital Citizenship|Governance")
		
	* social/ character/character 
	g SocChar_character = regexm(skill, "Growth Mindednes|Energestic|Energetic|Self-Starter|Initiative|Driven Personality|Self-Motivation|Visionary|Competent|Achieving|Hardworking|Self Evaluation|Reliable|Punctual|Resistent to Stress|Independent|Cultural Awareness|Positive Disposition|Business Etiquette|Cultural Responsiveness|Cultural Sensitivity|Diversity|Intercultural Competence|Compassion|Quick Learning")
		
	* social/ Customer service/Customer service 
	g SocCusServ_cservice = regexm(skill, "Customer|Sales|Client|Patient|Buy|Purchase|Repetitive Customer Service|Tactfulness|Courtesy|Helpfulness|Customer Support|Selling|Advise|Brand Representation")
		
	* social/ People management/People management 
	g SocPeopManag_peopmanag = regexm(skill, "Supervisory|Leadership|Performance Management|Personnel Management|People Management|Staff Management|Team Management|Mentor|Staff Supervision|Staff Development|Organizational Development|Crisis Management|Conflict Resolution|Coach|Human Resource Management|Human Capital Management|Career Development|Employee Handbook Developmen|Executive Development|High-Potential Development|Key Opinion Leader Development|Learning And Development Strategy|Partner Development|Personality Development|Training And Development|Workforce Development|Working With The Developmentally Disabled|Capability Development|Personnel and Development|Career Counseling|Motivational Interviewing|Positive Behavior Interventions and Supports|Positive Behavior Support")
		
	* social/ Creativity/Creativity
	g SocCrea_creativity = regexm(skill, "Creativ|Innovative|Inventiveness|Curiosity|White Space Development")
		
	egen social = rsum(Soc*)
	
		replace SocChar_orgskills = 0 if SocSoc_communication==1
		replace SocChar_orgskills = 0 if SocCusServ_cservice==1
		
		g aux = regexm(skill, "Team") if social==2
		foreach var of varlist SocSoc_teamwork  {
		replace `var' = 0 if `var'==1 & aux==1 & SocPeopManag_peopmanag==1
	}
	
		
	drop aux
	capture drop social
	egen social = rsum(Soc*)

	**////////////////////////////Manual////////////////////////////
	
	* Manual/ Finger dexterity/ Finger dexterity
	g ManFingdex_fingerdextery = regexm(skill, "Picking|Sorting|Repetitive Assembly|Mixing Ingredients|Baking|Dicing|Mincing|Sewing|Decorative Trimming|Operating Tabulating Machines|Packing Agricultural Produc|Control|Equip|Operate|Repetitive Movements|Fine Motor Skills|Manual Coordination|Hand-Eye Coordination|Dexterity|Manipulative Skill|Tool Hand|Craft|Tactile|Assembling|Artisan|Calligrap|Sculpting|Carpentr|Nail Care|Hair Care|Skin Care|Personal Care")
		
	* Manual/ Hand-foot-eye coordination/ Hand-foot-eye coordination
	g ManHand_handfooteye = regexm(skill, "Packaging And Labeling|Attend Cattle|Attend Other Animals|Prune Ornamental and Shade Trees|Perform Gymnastic Feats|Accommodate|Renovate|Repair|Restore|Serve|Passenger Service|Clean|React on Time|Fine Manipulations|Caprine And Ovine Care|Horse Care|Animal Care|Handling|Cooking|Grilling|Frying|Snow Removal|Pruning|Landscape Maintenance|Groundskeeping|Grubbing|Gardening")
		
	* Manual/ Driving/ Hand-foot-eye coordination
	g ManDrive_handfooteye = regexm(skill, "Drive to Transport Passengers|Drive to Transport Charge|Driver's License|Safe Driving|Defensive Driving|Vehicle Operation|Road Safety|Transportation|Commercial Driver|Delivery Driver|Order Delivery|Courier Services|Package Delivery|Shuttle Service|Public Transportation|Fleet Management|Drive Testing")
	
	* Manual/ flying/ Hand-foot-eye coordination
	g ManFly_handfooteye = regexm(skill, "Pilot Airplanes|Aviation|Flight Operations|Aircraft Handling|Navigation Skills|Aeronautics|Air Navigation|Flight Simulator|Aerial Maneuvering|Precision Landing|Parachute Operation|Flight Instructor|Airline Transport Pilot|Helicopter Operation|Unmanned Aerial Vehicle (UAV)|Rotorcraft|Multi-Engine Land|Airfield Operations|Flight Safety|Flight Test Instrumentation")
		
	* Manual/ Physical/ Physical
	g ManPhy_physical = regexm(skill, "Resistance|Walk|Run|Carry Heavy Loads|Baggage Services|Cycling|Heavy Equipment Operation|Physical Fitness|Strength|Endurance|Agility|Personal Security|Physical Security|Security Guard|Firefighting|Lifeguard|Perform Other Sports Requiring Skill and Balance")
	
	
	egen manual = rsum(Man*)
	
	egen skills_identified = rsum(cognitive social manual)

	**////////////////////////////Additionals to clasiffy////////////////////////////
	
	g add_products = regexm(skill, "Retail Industry Knowledge|Marketing|Purchasing|Merchandising|Product Development|Procurement|Product Management|Inventory Management|Inventory Control|Product Knowledge|E-Commerce|Account Management|Description and Demonstration of Products|Cross Sell|Supply Chain Management|Retail Management|Advertising|Inventory Maintenance|Marketing Management|Market Strategy|Product Marketing|Product Design|Market Planning|New Product Development|Supplier Development|Account Development|Audience Development|Market Development|Service Development|Standard Operating Procedures Development|Flavor Development|Fragrance Development|Look Development|Procedure Development|Process Development|Process Driven Development|Infrastructure Security|Food Security|Industrial Security|Physical And Environmental Security|Supply Chain Security|Product Testing")
	
	g add_securityss = regexm(skill, "ADT Security Services|Airport Security|Airport Security Clearance|Casino Security|Container Security|Corporate Security|Enterprise Security|Crime Scene Security|Door Security|General Security|Local Security|Maritime Security|Military Security|Multilevel Security|Offensive Security|Perimeter Security|Security Strategies|Security Studies|Harbor Security|Security Awareness|Qualified Security Assessor|Security Investigations|Operations Security|Security Administration|Security Camera Monitoring|Security Clearance|Security Identification Display Area (SIDA) Badge|Security Policies|Security Recommendations|Vessel Security|Transmission Security|Security Domain|Security Context|Sensitive Security Information|Cargo Security|Security Accounts Manager|Security Implementation|Security Interest|Security Lighting|Content Security Policy|Security Seal|Security Patterns|Security Operations|SecOps|Security Liaison|Information Security Audits|Site Security")
	
	g add_admsupport = regexm(skill, "Administrative Support|General Office Duties|Office Management|Appointment Setting|Record Keeping|Administrative Functions|General Office Duties|Secretarial Skills|Travel Arrangements|Front Office|Expense Reports|Copying|Clerical Duties|Word Processing|Mailing|Typing|Telephone Skills|Digital Assets")
	
	g add_sales_rs = regexm(skill,"Salesforce|Sales Reporting|Sales Analysis|Sales Planning|Sales Forecasting|Sales Order Processing|Sales Tax Returns|Land Development|Residential Development|Mixed-Use Development")
		
	g mgt = regexm(skill, "Management")
	g add_management = (mgt == 1 & cognitive==0 & social==0 & manual==0 & digital==0)
		drop mgt
	
	g add_technicalStem = regexm(skill, "Certified|Certification|Engineer|Physics|Biolog|Solar|Low Carbon|ACI Concrete Field Testing Technician|Aquifer|Battery|Boundary Testing|Circuit Testing|Construction Materials Testing|Electromagnetic Testing|Fabrication And Testing Of Optical Components|Fiber Optic Testing|Field Testing|Flight Testing|Hydraulic Testing|Hydrostatic Testing|Integrity Testing|Materials Testing|Microbiological Testing|Microhardness Testing|Nuclear Weapons Testing|Radiographic Testing|Thermal Vacuum Testing|Ultrasonic Testing|Universal Testing Machines|Volume Testing|Wafer Testing|Water Testing|Thermal|Soil Testing|Stability Testing|Well Testing|Sand Equivalent Testing|Liquid|Emission|Airspace|Airworthiness|Supplemental Type Certificates|Vertical Take-Off And Landing|Flying Qualities|Structural|Tunnels|Pump Stations|Superstructure")
		
	g add_technicalEdu = regexm(skill, "E-Learning Development|Online Course Development|Academic|Scientific Literature|Faculty Development|Syllabus Development|Language Development|Curriculum Development|Adult Development|Competency-Based Development|Employability Development|Learning Development|Life Skills Development|Capacity Development|Cognitive Development|Child Development|Human Development|Content Development|Course Development|Education|Student|Digital Learning Technology")
		
	g add_technicalHeal = regexm(skill, "Medical|Medicine|Health|Psycho|Vaccine|Disorder|Drug|Disabilities|Clinical|Natal|Neonatal|Prenatal|Postpartum|Postnatal|Pediatric|Palliative|Perinatal|Perineal|Perioperative|Developmental Stage Theories|Acute Care|Trauma|Surgical|Ambulatory Care|Cancer|Neuro|Bedside Care|Burn Care|Coronary|Respiratory|Critical Care|Dementia Care|Dental Care|Inpatient Care|Integrated Care|Intensive Care|Long Term Care Professional|Anesthesia|Oral Care|Post-Mortem Care|End-of-Life Care|Care Guidelines|Urgent Care|Primary Care|Chronic Care|Care Unit|Continuing Care|Evaluation Of Care|Follow-Up Care|Care Coordination|Care Map|Managed Care|Nursing Care|Nutrition Care|Point-Of-Care Testing|Preventive Care|Postoperative Care|Preoperative Care|Secondary Care|Transitional Care|Value-Based Care|Wound Care|Point Of Care Charting|Radiography|Pathology|Blood|Cardiac|Endotoxin|Genetics|Genomic|Glucose|Hearing|Mantoux|Pharma|Pulmon|Allergy|Therapy|Ambulance|Geriatric Syndromes|Geriatrics|Aging Processes|Orofacial Granulomatosis|Talking Therapies")
	
	g add_technicalSS = regexm(skill, "Development Aid|Development Economics|Development Environment|Sustainable Development|Development Studies|Economic Development|Environmental Policy Development|Policy Development|Social Development|Census Development|Development Interventions|Rural Development|Survey Development|Transit-Oriented Development|Social Security|Audit")
		
		
	g add_technicalLaw = regexm(skill, "Law|Regulatory|Justice|Constitution|Act|Regulation|Legal|Statutory|Data Protection Strategy|Data Privacy Laws")
	
	g add_careservices = regexm(skill, "Caregiving|Bereavement Care|Family Child Care|Infant Care|Elderly Care|Long-Term Care|Nursing Home Care|Kinship Care|Respite Care|Senior Living|Geriatric Nursing|Gerontological Nursing|Fall Prevention")
	
	
	egen adds = rsum(add_*)
		
	************************************************************** skills identification
	capture drop skills_identified
	egen skills_identified = rsum(cognitive social manual adds)
	
	gen categoria=0
	replace categoria=1 if cognitive>0
	replace categoria=2 if digital>0
	replace categoria=3 if social>0
	replace categoria=4 if manual>0
	replace categoria=5 if adds>0
	
	label define categoria 0 "Non identified" 1 "Cognitive" 2 "Digital" 3 "Social" 4 "Manual" 5 "additionals"
	label values categoria categoria
	tab categoria
	
	gen identificado=0
	replace identificado=1 if cognitive>0 | digital>0 | social>0 | manual>0 | adds>0
	
	
	*------------------------------------------------------------------------
	* 2 -- complementando la clasificacion utilizando subcategory *Lightcast*
	*------------------------------------------------------------------------
	
	*****************************

		* Cognitive
		
		replace CogCog_thinking = 1 if (identificado == 0) & (subcategory=="Critical Thinking and Problem Solving" | subcategory=="General Science and Research")
		
		replace CogCog_math = 1 if (identificado == 0) & (subcategory=="Statistics" | subcategory=="Mathematics and Mathematical Modeling")
		
		replace  CogWri_communication = 1 if (identificado == 0) & (subcategory=="Communication" | subcategory=="Writing and Editing" | subcategory=="Journalism" | subcategory=="Content Development and Management" | subcategory=="Language Interpretation, Translation, and Studies" | subcategory=="Literature and Literary Studies" | subcategory=="Document Management")
		
		replace CogDA_dataanalysis = 1 if (identificado == 0) & (subcategory=="Data Analysis")
	
		replace CogProMan_proman = 1 if (identificado == 0) & (subcategory=="Project Management" | subcategory=="Program Management")
		
		replace CogFin_financial = 1 if (identificado == 0) & (subcategory=="Financial Advisement" | subcategory=="Tax" | subcategory=="Accounts Payable and Receivable" | subcategory=="Billing and Invoicing" | subcategory=="Payment Processing and Collection"  | subcategory=="Payroll" | subcategory=="Financial Accounting" | subcategory=="Financial Analysis" | subcategory=="Financial Management" | subcategory=="Financial Modeling" | subcategory=="Financial Reporting" | subcategory=="Financial Trading" | subcategory=="Investment Management" | subcategory=="General Accounting" | subcategory=="Specialized Accounting" | subcategory=="Budget Management" | subcategory=="Auditing" | subcategory=="Account Management" | subcategory=="Cost Accounting" | subcategory=="Structured Finance" | subcategory=="General Finance" | subcategory=="Sales Analysis" | subcategory=="General Lending" | subcategory=="Banking Services" | subcategory=="Insurance" | subcategory=="Cash Management" | subcategory=="Cryptocurrency" | subcategory=="Financial Regulation" | subcategory=="Mortgage Lending" | subcategory=="Commercial Lending")
		
		replace CogBusS_qualityac = 1 if (identificado == 0) & (subcategory=="Quality Assurance and Control" | subcategory=="Process Improvement and Optimization")
		
		replace CogBusA_busanalysis = 1 if (identificado == 0) & (subcategory=="Market Analysis" | subcategory=="Business Strategy" | subcategory=="Business Analysis" | subcategory=="Business Consulting" | subcategory=="Business Intelligence" | subcategory=="Risk Management" | subcategory=="Business Continuity" | subcategory=="Business Management" | subcategory=="Business-to-Business (B2B) Sales" | subcategory=="Business Operations" | subcategory=="Pricing Analysis" | subcategory=="Marketing Strategy and Techniques")
		
		replace CogBusS_systems = 1 if  (identificado == 0) & (subcategory=="Business Solutions" | subcategory=="Business Intelligence Software") 
		
		replace CogLan_language = 1 if  (identificado == 0) & (subcategory=="Language Competency")
		
		
		* Digital
		
		replace Digital_basic = 1 if (identificado == 0) & (subcategory=="Microsoft Windows" | subcategory=="Microsoft Development Tools" | subcategory=="Middleware" | subcategory=="Office and Productivity Software" | subcategory=="iOS Development" | subcategory=="Basic Technical Knowledge")
		
		replace Digital_interm = 1 if (identificado == 0) & (subcategory=="Social Media" | subcategory=="Statistical Software" | subcategory=="Marketing Software" | subcategory=="Accounting and Finance Software" | subcategory=="Science Software" | subcategory=="Human Resources Software" | subcategory=="Engineering Software" | subcategory=="Anti-Malware Software" | subcategory=="Collaborative Software" | subcategory=="Networking Software" | subcategory=="Graphic and Visual Design Software" | subcategory=="Simulation and Simulation Software" | subcategory=="Backup Software" | subcategory=="Mathematical Software" | subcategory=="Software Quality Assurance" | subcategory=="Education Software and Technology" | subcategory=="Search Engines" | subcategory=="Web Services" | subcategory=="Computer Hardware" | subcategory=="Networking Hardware" | subcategory=="Hardware Description Languages (HDL)" | subcategory=="Electronic Hardware" | subcategory=="Technical Support and Services" | subcategory=="Video and Web Conferencing" | subcategory=="Data Management" | subcategory=="Databases")
		
		replace Digital_advanced = 1 if (identificado == 0) & (subcategory=="Data Science" | subcategory=="Data Visualization" | subcategory=="Artificial Intelligence and Machine Learning (AI/ML)" | subcategory=="Natural Language Processing (NLP)" | subcategory=="Java" | subcategory=="C and C++" | subcategory=="Apache"  | subcategory=="JavaScript and jQuery"  | subcategory=="Software Development" | subcategory=="Software Development Tools"  | subcategory=="Agile Software Development" | subcategory=="Web Design and Development" | subcategory=="Web Content" | subcategory=="Web Analytics and SEO" | subcategory=="Scripting" | subcategory=="Scripting Languages" | subcategory=="Cybersecurity" | subcategory=="Animation and Game Design" | subcategory=="Audio Production and Technology" | subcategory=="IT Management" | subcategory=="Internet of Things (IoT)" | subcategory=="Network Protocols" | subcategory=="General Networking" | subcategory=="Network Security" | subcategory=="Digital Design" | subcategory=="Cloud Computing" | subcategory=="Web Services" | subcategory=="Application Programming Interface (API)" | subcategory=="Cloud Solutions" | subcategory=="Network Security"| subcategory=="Web Analytics and SEO" | subcategory=="User Interface and User Experience (UI/UX) Design" | subcategory=="Software Quality Assurance" | subcategory=="Virtualization and Virtual Machines" | subcategory=="Computer Science" | subcategory=="Firmware" | subcategory=="Augmented and Virtual Reality (AR/VR)" | subcategory=="Blockchain" | subcategory=="Query Languages" | subcategory=="Servers" | subcategory=="System Design and Implementation" | subcategory=="Systems Administration" | subcategory=="Test Automation" | subcategory=="Geospatial Information and Technology" | subcategory=="IT Automation" | subcategory=="Identity and Access Management" | subcategory=="Operating Systems" | subcategory=="Other Programming Languages" | subcategory=="Data Storage" | subcategory=="Database Architecture and Administration")
		
		
		* Social
		
		replace SocSoc_communication = 1 if (identificado == 0) & (subcategory=="Business Communications" | subcategory=="Public Relations") 
		
		replace SocSoc_general = 1 if (identificado == 0) & (subcategory=="Personal Attributes" | subcategory=="Social Skills")
		
		replace SocChar_orgskills = 1 if (identificado == 0) & (subcategory=="Human Resources Management and Planning"  | subcategory=="Compensation and Benefits" | subcategory=="Scheduling")
		
		replace SocCusServ_cservice = 1 if (identificado == 0) & (subcategory=="Customer Service" | subcategory=="Sales Management" | subcategory=="Specialized Sales" | subcategory=="Retail Sales" | subcategory=="Real Estate Sales" | subcategory=="General Sales Practices" | subcategory=="Customer Relationship Management (CRM)" | subcategory=="Client Support" | subcategory=="Retail Sales")
		
		replace SocPeopManag_peopmanag= 1 if (identificado == 0) & (subcategory=="Employee Relations" | subcategory=="People Management" | subcategory=="Recruitment" | subcategory=="Employee Training" | subcategory=="Coaching and Athletic Training" | subcategory=="Counseling Services")
	
		
		* Manual
		
		replace ManFingdex_fingerdextery = 1 if (identificado == 0) & (subcategory=="Carpentry" | subcategory=="Hand Tools" | subcategory=="Power Tools")
		
		replace ManHand_handfooteye = 1 if (identificado == 0) & (subcategory=="Concrete and Masonry" | subcategory=="Cleaning and Janitorial Services" | subcategory=="General Shipping and Receiving")
		
		replace ManPhy_physical = 1 if (identificado == 0) & (subcategory=="Dance" | subcategory=="Physical Abilities" | subcategory=="Sports and Recreation")
		
		replace ManDrive_handfooteye = 1 if (identificado == 0) & (subcategory=="Heavy Equipment Operation" | subcategory=="Transportation Operations" | subcategory=="Ground Passenger Transportation" | subcategory=="Ground Freight Transportation" | subcategory=="Rail Transportation" | subcategory=="Sea and Waterway Transportation" | subcategory=="Transportation Equipment Manufacturing" )
		
		replace ManFly_handfooteye=1  if (identificado == 0) & (subcategory=="Air Transportation") 
		
	
		* Additionals
		replace add_products = 1 if (identificado == 0) & (subcategory=="Inventory and Warehousing" | subcategory=="Logistics" | subcategory=="Product Development" | subcategory=="Product Management" | subcategory=="Product Inspection" |  subcategory=="Production and Assembly" | subcategory=="Transportation Equipment Manufacturing" | subcategory=="Lean Manufacturing" | subcategory=="Metal Fabrication" | subcategory=="Manufacturing Standards" | subcategory=="Manufacturing Design" | subcategory=="Supplier Management" | subcategory=="Supply Chain Management" | subcategory=="Plant Operations and Management" | subcategory=="Company, Product, and Service Knowledge"  | subcategory=="Procurement")
		
		replace add_technicalStem = 1 if (identificado == 0) & (subcategory=="Chemistry" | subcategory=="Aerospace Engineering" | subcategory=="Agricultural Research and Agronomy" | subcategory=="Air Quality and Emissions" | subcategory=="Automation Engineering" | subcategory=="Automotive Technologies" | subcategory=="Basic Electrical Systems" | subcategory=="Biology" | subcategory=="Biotechnology" | subcategory=="Clean Energy" | subcategory=="Telecommunications" | subcategory=="Mechanical Engineering" | subcategory=="Manufacturing Processes" | subcategory=="Molecular, Cellular, and Microbiology" | subcategory=="Laboratory Research" | subcategory=="Earth and Space Science"| subcategory=="Materials Science and Engineering" | subcategory=="Engineering, Scientific, and Technical Instruments" | subcategory=="Physics" | subcategory=="Oil and Gas" | subcategory=="Pharmacology and Drug Discovery" | subcategory=="Geological Engineering" | subcategory=="Materials Science and Engineering" | subcategory=="Electrical and Computer Engineering" | subcategory=="Computer Science" | subcategory=="Drafting and Engineering Design" | subcategory=="Green Architecture" | subcategory=="Marine and Naval Engineering" | subcategory=="Chemical and Biomedical Engineering" | subcategory=="Process Engineering" | subcategory=="Mining Engineering" | subcategory=="Industrial Engineering" | subcategory=="Wind Energy" | subcategory=="Electromechanical Engineering" | subcategory=="Architectural Design" | subcategory=="Electronics Engineering" | subcategory=="Civil and Architectural Engineering" | subcategory=="Engineering Practices" | subcategory=="Environmental Engineering and Restoration" | subcategory=="Optical Engineering" | subcategory=="Robotics" | subcategory=="Bioinformatics" | subcategory=="Clinical Informatics" | subcategory=="Wireless Technologies" | subcategory=="Mobile Development")
			
		replace add_technicalHeal = 1 if (identificado == 0) & (subcategory=="Anesthesiology" | subcategory=="Blood Collection" | subcategory=="Cardiology" | subcategory=="Dermatology" | subcategory=="Ear, Nose, and Throat" | subcategory=="Emergency and Intensive Care" | subcategory=="Endocrinology" | subcategory=="Eye Care" | subcategory=="First Aid" | subcategory=="Gastroenterology"	| (subcategory=="General Medical Tests and Procedures" & skill!="Dressing Changes") | subcategory=="General Medicine" | subcategory=="Genetic Disorders" | subcategory=="Genetics" 	| subcategory=="Hematology" | subcategory=="Hepatology" | subcategory=="Inmunology" | subcategory=="Infectious Diseases" | subcategory=="Injury Treatment"  | subcategory=="Medical Imaging" | (subcategory=="Medican Science and Research" & skill!="Scientific Literature") | subcategory=="Medical Support" | subcategory=="Mental Health Diseases and Disorders" | ( subcategory=="Mental Health Therapies" & skill!="Motivational Interviewing" & skill!="Peer Support" & skill!="Positive Behavior Interventions and Supports" & skill!="Positive Behavior Support") | subcategory=="Mental and Behavioral Health Specialties" | subcategory=="Nephrology"  | subcategory=="Neurology" | subcategory=="Neuroscience" | subcategory=="Nursing and Patient Care" | subcategory=="Nutrition and Diet"  | subcategory=="Obstetrics and Gynecology (OBGYN)" | subcategory=="Oncology" | subcategory=="Orthopedics" | subcategory=="Pathology" | subcategory=="Pediatrics" | subcategory=="Physical Therapy" | subcategory=="Public Health and Disease Prevention" | subcategory=="Pulmonology" | subcategory=="Rehabilitation" | subcategory=="Surgery" | subcategory=="Urology" | subcategory=="Oral and Dental Care" | subcategory=="Health Information Management and Medical Records" | subcategory=="Nuclear Medicine" | subcategory=="General Medical Tests and Procedures" | subcategory=="Health Care Administration" | subcategory=="Nuclear Medicine" | subcategory=="Clinical Trials" | subcategory=="Immunology" | subcategory=="Health Information Management and Medical Records" | subcategory=="Health Care Procedure and Regulation" | subcategory=="Medical Billing and Coding" | subcategory=="Medical Equipment and Technology" | subcategory=="Pharmacy" | subcategory=="Medical Science and Research" | subcategory=="Speech Language Pathology" | subcategory=="Animal Health and Veterinary Medicine")
		
		replace add_careservices = 1 if (identificado == 0) & (subcategory=="Home Health Care and Assisted Living" | subcategory=="Child Care")
		
		replace add_technicalSS = 1 if (identificado == 0) & (subcategory=="Social Studies" | subcategory=="Economics" | subcategory=="Policy Analysis, Research, and Development") 
		
		replace add_technicalLaw = 1 if (identificado == 0) & (subcategory=="Regulation and Legal Compliance" | subcategory=="Legal Proceedings" | subcategory=="Law Enforcement and Criminal Justice" | subcategory=="Property Law" | subcategory=="Litigation and Civil Justice" | subcategory=="Legal Support")
		
		replace add_technicalEdu = 1 if (identificado == 0) & (subcategory=="Teaching" | subcategory=="Higher Education" | subcategory=="Special Education" | subcategory=="Training Programs" | subcategory=="Employee Training" | subcategory=="Childhood Education and Development" | subcategory=="Instructional and Curriculum Design")
		
		replace add_admsupport = 1 if (identificado == 0) & (subcategory=="Office Management" | subcategory=="Administrative Support and Clerical Tasks")
		
		replace add_securityss = 1 if (identificado == 0) & (subcategory=="Physical Security" | subcategory=="Transportation Security" | subcategory=="Safety and Security" | subcategory=="Safety and Surveillance Technology")
		
		replace add_sales_rs = 1 if identificado==0 & (subcategory=="Merchandising" | subcategory=="Cash Register Operation")
		
		g add_repair_mach = ((identificado == 0) & (subcategory=="Vehicle Repair and Maintenance" | subcategory=="Machine Tools" | subcategory=="Machinery" | subcategory=="General Repairs and Maintenance" | subcategory=="Equipment Repair and Maintenance" | subcategory=="Appliance Repair and Maintenance" | subcategory=="Circuitry" | subcategory=="HVAC"))
	
		g add_media_production = ((identificado == 0) & (subcategory=="Photo/Video Production and Technology" | subcategory=="Media Production" | subcategory=="Graphic and Visual Design" | subcategory=="Promotions and Campaigns" | subcategory=="Digital Marketing" | subcategory=="Streaming Media Systems" | subcategory=="Creative Design" | subcategory=="Presentation Design" | subcategory=="Advertising" | subcategory=="Online Advertising" | subcategory=="Content Development and Management" | subcategory=="Brand Management"))
		
		g add_art_art = ((identificado == 0) & (subcategory=="Art and Illustration" | subcategory=="Music" | subcategory=="Theatre and Performance Art" | skill=="Artistic Development" | skill=="Digital Arts"))
		
		g add_enviroment = ((identificado == 0) & (subcategory=="Integrated Development Environments (IDEs)" | subcategory=="Environmental Regulations" | subcategory=="Climate Change" | subcategory=="Environmental Geology" | subcategory=="Waste Management" | subcategory=="Ecology" | subcategory=="Environment and Resource Management"))
		
		g add_energy_energy = ((identificado == 0) & (subcategory=="Solar Energy" | subcategory=="Water Energy" | subcategory=="Nuclear Energy" | subcategory=="Energy Efficiency" | subcategory=="Power Generation" | subcategory=="Energy Management" | subcategory=="Natural Gas" | subcategory=="Electrical Power"))
		
		g add_construction_activities = ((identificado == 0) & (subcategory=="General Construction and Construction Labor" | subcategory=="Construction Inspection" | subcategory=="Construction Management" | subcategory=="Construction Painting" | subcategory=="Road and Bridge Construction" | subcategory=="Electrical Construction" | subcategory=="Welding, Brazing, and Soldering" | subcategory=="Plumbing"))
		
		g add_militar_activities = ((identificado == 0) & (subcategory=="Military Operations" | subcategory=="Military Technology and Weapons"))
	
		g add_agriculture_activities = ((identificado == 0) & (subcategory=="Forestry" | subcategory=="Agricultural Management and Operations" | subcategory=="Aquaculture" | subcategory=="Agriculture and Crop Farming"))
	
	
	capture drop cognitive digital social manual adds skills_identified
	
	egen cognitive = rsum(Cog*)
	
	egen digital = rsum(Dig*)

	egen social = rsum(Soc*)
	
	egen manual = rsum(Man*)

	egen adds = rsum(add_*)

	egen skills_identified = rsum(cognitive digital social manual adds)
	
	
	*------------------------------------------------------------------------
	* 3 -- taxonomia final
	*------------------------------------------------------------------------
	
	
	g skill_tax=0
	replace skill_tax=1 if cognitive>0
	replace skill_tax=2 if digital>0
	replace skill_tax=3 if social>0
	replace skill_tax=4 if manual>0
	replace skill_tax=5 if adds>0
	
	label define skill_tax 0 "Non identified" 1 "Cognitive" 2 "Digital" 3 "Social" 4 "Manual" 5 "Technicals"
	label values skill_tax skill_tax
	
	g cognitive_type = (skill_tax==1)
		replace cognitive_type = . if skill_tax != 1
		replace cognitive_type = 1 if CogCog_thinking == 1
		replace cognitive_type = 2 if CogCog_math == 1
		replace cognitive_type = 3 if CogWri_communication == 1
		replace cognitive_type = 4 if CogFin_financial == 1
		replace cognitive_type = 5 if CogBusS_systems  == 1
		replace cognitive_type = 6 if CogBusS_qualityac == 1
		replace cognitive_type = 7 if CogBusA_busanalysis == 1
		replace cognitive_type = 8 if CogProMan_proman == 1
		replace cognitive_type = 9 if CogDA_dataanalysis == 1
		replace cognitive_type = 10 if CogLan_language == 1
		replace cognitive_type = 11 if CogAdap_adaptability == 1
		la def cognitive_type 1 "thinking" 2 "math" 3 "communication" 4 "financial" 5 "bussystems" 6 "qualitycontrol" 7 "busanalysis" 8 "projectmgmt" 9 "dataanalysis" 10 "language" 11 "adaptability"
		la values cognitive_type cognitive_type
		
	g digital_type = (skill_tax==2)
		replace digital_type = . if skill_tax !=2
		replace digital_type = 1 if Digital_basic == 1
		replace digital_type = 2 if Digital_interm == 1
		replace digital_type = 3 if Digital_advanced == 1
		la def digital_type 1 "digbasic" 2 "diginterm" 3 "digadvanced"
		la values digital_type digital_type
	
	g social_type = (skill_tax==3)
		replace social_type = . if skill_tax != 3
		replace social_type = 1 if SocSoc_teamwork == 1
		replace social_type = 2 if SocSoc_communication == 1
		replace social_type = 3 if SocSoc_general == 1 
		replace social_type = 4 if SocChar_orgskills == 1
		replace social_type = 5 if SocChar_character == 1 
		replace social_type = 6 if SocCusServ_cservice == 1
		replace social_type = 7 if SocPeopManag_peopmanag == 1
		replace social_type = 8 if SocCrea_creativity == 1
		la def social_type 1 "teamwork" 2 "communication" 3 "general" 4 "orgskills" 5 "character" 6 "custservice" 7 "peoplemgt" 8 "creativity" 
		la values social_type social_type
			
	g manual_type = (skill_tax==4)
		replace manual_type = . if skill_tax != 4
		replace manual_type = 1 if ManFingdex_fingerdextery == 1
		replace manual_type = 2 if ManHand_handfooteye == 1
		replace manual_type = 3 if ManDrive_handfooteye == 1
		replace manual_type = 4 if ManFly_handfooteye == 1
		replace manual_type = 5 if ManPhy_physical == 1
		la def manual_type 1 "fdexerity" 2 "handfooteye" 3 "driving" 4 "flying" 5 "physical"
		la values manual_type manual_type
			
	g adds_type = (skill_tax==5)
		replace adds_type = . if skill_tax != 5
		replace adds_type = 1 if add_products == 1
		replace adds_type = 2 if add_technicalStem == 1
		replace adds_type = 3 if add_technicalHeal == 1
		replace adds_type = 4 if add_careservices == 1
		replace adds_type = 5 if add_technicalSS == 1
		replace adds_type = 6 if add_technicalLaw == 1
		replace adds_type = 7 if add_technicalEdu == 1	
		replace adds_type = 8 if add_admsupport == 1
		replace adds_type = 9 if add_securityss == 1	
		replace adds_type = 10 if add_sales_rs == 1
		replace adds_type = 11 if add_management == 1
		replace adds_type = 12 if add_repair_mach == 1
		replace adds_type = 13 if add_media_production == 1
		replace adds_type = 14 if add_art_art == 1
		replace adds_type = 15 if add_enviroment == 1
		replace adds_type = 16 if add_energy_energy == 1
		replace adds_type = 17 if add_construction_activities == 1
		replace adds_type = 18 if add_militar_activities == 1
		replace adds_type = 19 if add_agriculture_activities == 1
		la def adds_type 1 "products" 2 "stem" 3 "health" 4 "caress" 5 "socialsciences" 6 "law" 7 "education" 8 "admsupport" 9 "securityss" 10 "sales"  11 "management" 12 "repairmach" 13 "mediaprod" 14 "art" 15 "environment" 16 "energy" 17 "construction" 18 "militar" 19 "agric"
		la values adds_type adds_type
		

		save "$data/cleaned/skills_`ctr'4_cat&noncat.dta", replace
	
	}
	
*4.1) Chile skills classification 

import delimited "$data\raw\CHL_skills.csv", clear 

run "$code\CHL_skills_tax.do"

*5) Argentina - Postings and skills 

clear all 

import delimited "$data\raw\ARG_skills.csv"
keep id skill_name
ren skill_name skill

	save "$data\raw\ARGid&skill.dta", replace
	
merge m:1 id using "$data\cleaned\ARG_postingsout.dta"
ren _merge check

merge m:1 skill using "$data\cleaned\skills_ARG4_cat&noncat.dta"


* count postings
sort id
by id: gen num_postings = _n
	replace num_postings = 0 if num_postings!=1

drop if _merge==2 

save "$data\cleaned\postings&skillsARGout.dta", replace


*6) Uruguay - Postings and skills 

use "$data\cleaned\postingsURY_out.dta", clear 

ren skill_name skill
drop  is_software

ren _merge aux  

merge m:1 skill using "$data\cleaned\skills_URY4_cat&noncat.dta", keep(master match)
ren _merge check

ren aux _merge 

* count postings
sort id
by id: gen num_postings = _n
	replace num_postings = 0 if num_postings!=1
	
save "$data\cleaned\postings&skillsURYout.dta", replace


*6.1) Chile - Postings and skills 

import delimited "$data\raw\CHL_skills.csv", clear

keep id skill_name
ren skill_name skill

	save "$data\raw\CHLid&skill.dta", replace

merge m:1 id using "$data\cleaned\CHL_postingsout.dta"
ren _merge check

merge m:1 skill using "$data\cleaned\skills_CHL4_cat&noncat.dta"
ta _merge

* count postings
sort id
by id: gen num_postings = _n
	replace num_postings = 0 if num_postings!=1
	
drop if _merge == 2

save "$data\cleaned\postings&skillsCHLout.dta", replace


*6.2) USA - Postings and skills 

run "$code\USA_skills_tax.do"

run "$code\USA_data_setup.do"

*7) Argentina, Chile, Uruguay and United States - Postings and skills - Classified   

local ctrs "ARG CHL URY US"

local cnt = 1 

foreach ctr of local ctrs {

	use "$data\cleaned/postings&skills`ctr'out.dta", clear 

	drop if skill_tax == 0

		* ------> count postings by skill // 

	forvalues i = 1(1)5 {
		egen count_tax`i' = total(skill_tax) if skill_tax==`i', by(id)
		egen posting_tax`i' = max(count_tax`i'), by(id)
			replace posting_tax`i' = 1 if posting_tax`i'!=. & num_posting==1
			replace posting_tax`i' = 0 if posting_tax`i'==. & num_posting==1
			replace posting_tax`i' = . if num_posting!=1
	}


*---------------------------------------------------------
* ------> count postings by skill_type (in demand skills) UNIT: POSTINGS
*---------------------------------------------------------
		
* cognitive type	
	
	forvalues i = 1(1)11   {
	    egen count_cognitive`i' = total(cognitive_type) if cognitive_type==`i', by(id)
		egen posting_cognitive`i' = max(count_cognitive`i'), by(id)
			replace posting_cognitive`i' = 1 if posting_cognitive`i'!=. & num_posting==1
			replace posting_cognitive`i' = 0 if posting_cognitive`i'==. & num_posting==1
			replace posting_cognitive`i' = . if num_posting!=1
	}

	egen cogcount = rsum(posting_cognitive*) if num_posting==1 

	egen posting_cognitive_tot = rsum(posting_cognitive*)
		replace posting_cognitive_tot = 1 if  posting_cognitive_tot>1 
		replace posting_cognitive_tot = . if  num_posting!=1


	
	* digital type

	forvalues i = 1(1)3   {
		egen count_digital`i' = total(digital_type) if digital_type==`i', by(id)
		egen posting_digital`i' = max(count_digital`i'), by(id)
			replace posting_digital`i' = 1 if posting_digital`i'!=. & num_posting==1
			replace posting_digital`i' = 0 if posting_digital`i'==. & num_posting==1
			replace posting_digital`i' = . if num_posting!=1
	}
		
	egen digcount = rsum(posting_digital*) if num_posting==1 

	egen posting_digital_tot = rsum(posting_digital*)
		replace posting_digital_tot = 1 if  posting_digital_tot>1 
		replace posting_digital_tot = . if  num_posting!=1

		
	* social type

	forvalues i = 1(1)8   {
		egen count_social`i' = total(social_type) if social_type==`i', by(id)
		egen posting_social`i' = max(count_social`i'), by(id)
			replace posting_social`i' = 1 if posting_social`i'!=. & num_posting==1
			replace posting_social`i' = 0 if posting_social`i'==. & num_posting==1
			replace posting_social`i' = . if num_posting!=1
		}
			
	egen soccount = rsum(posting_social*) if num_posting==1 
	
	egen posting_social_tot = rsum(posting_social*)
	replace posting_social_tot = 1 if  posting_social_tot>1 
	replace posting_social_tot = . if  num_posting!=1

	* manual type
	forvalues i = 1(1)5   {
			egen count_manual`i' = total(manual_type) if manual_type==`i', by(id)
			egen posting_manual`i' = max(count_manual`i'), by(id)
			replace posting_manual`i' = 1 if posting_manual`i'!=. & num_posting==1
			replace posting_manual`i' = 0 if posting_manual`i'==. & num_posting==1
			replace posting_manual`i' = . if num_posting!=1
		}
	
	egen mancount = rsum(posting_manual*) if num_posting==1 

	egen posting_manual_tot = rsum(posting_manual*)
	replace posting_manual_tot = 1 if posting_manual_tot>1
	replace posting_manual_tot = . if num_posting!=1
	
	
	* technical type 
	forvalues i = 1(1)19   {
		egen count_adds`i' = total(adds_type) if adds_type==`i', by(id)
		egen posting_adds`i' = max(count_adds`i'), by(id)
			replace posting_adds`i' = 1 if posting_adds`i'!=. & num_posting==1
			replace posting_adds`i' = 0 if posting_adds`i'==. & num_posting==1
			replace posting_adds`i' = . if num_posting!=1
		}	
	
	egen techount = rsum(posting_adds*) if num_posting==1 

	egen posting_tech_tot = rsum(posting_adds*) 
	replace posting_tech_tot = 1 if posting_tech_tot>1
	replace posting_tech_tot = . if num_posting!=1
	
	*---- count number of skills


	egen nskills = rsum(posting_cognitive1 posting_cognitive2 posting_cognitive3 posting_cognitive4 posting_cognitive5 posting_cognitive6 posting_cognitive7 posting_cognitive8 posting_cognitive9 posting_cognitive10 posting_cognitive11 	posting_digital1 posting_digital2 posting_digital3 posting_social1 posting_social2 posting_social3 posting_social4 posting_social5 posting_social6 posting_social7 posting_social8 posting_manual1 posting_manual2 posting_manual3 posting_manual4 	posting_manual5 posting_adds*)

	save "$data\cleaned/postings&skills`ctr'out_tax.dta", replace
	

}

*8) Argentina - EPH 2022 (second half) - ISCO-08

*Import raw data for the third and fourth quarters of 2022 and save as .dta file 

forvalues i = 3(1)4 {
	
	import delimited "$data\raw\usu_individual_T`i'22.txt", clear
	
	*Generate ISCO-08 

	**** isco 1 digit based on CNO 2001
	
	*Ocupados - codigo de correspondencia de https://www.aacademica.org/joserodriguez/74.pdf
	
	*Ocupados
	destring pp04b_cod, replace force
	replace pp04b_cod = pp04b_cod * 100 if pp04b_cod < 100
	tostring pp04b_cod, replace format(%04.0f)
	gen caes2=substr(pp04b_cod,1,2)
	destring caes2, replace force
	lab var caes2 "CAES ocupados (2 dígitos)"
	
	destring pp04d_cod, replace force
	recode pp04d_cod (1=11) (1001=11) (2001=26) (3001=11) (4001=11) (5001=13) (5002=14) (6001=13) (6002=99) (7001=12) (10111=24) (10112=33) ///
	(10113=41) (10122=33) (10123=41) (10131=24) (10132=33) (10133=41) (10201=24) (10202=33) (10203=41) (10311=24) (10312=33) (10313=41) ///
	(10314=42) (10322=33) (10323=41) (10331=24) (10332=34) (10333=41) (11111=26) (11112=34) (11113=41) (11131=26) (11132=34) (11201=26) ///
	(11202=34) (11203=41) (11311=26) (11312=34) (11313=41) (11323=41) (11331=26) (11332=34) (11333=41) (20111=24) (20112=33) (20113=43) ///
	(20131=24) (20132=33) (20133=43) (20201=24) (20202=33) (20203=43) (20311=24) (20312=33) (20313=43) (20314=41) (20323=43) (20331=24) ///
	(20332=42) (20333=42) (30111=24) (30112=33) (30113=52) (30123=52) (30131=24) (30132=33) (30133=52) (30201=24) (30202=33) (30203=52) ///
	(30311=24) (30312=33) (30313=52) (30314=52) (30323=52) (30331=24) (30332=33) (30333=52) (31111=24) (31112=33) (31113=52) (31123=52) ///
	(31131=24) (31132=33) (31133=52) (31202=33) (31311=24) (31312=33) (31313=52) (31314=52) (31323=52) (31331=24) (31332=33) (31333=52) ///
	(32111=24) (32112=33) (32113=52) (32123=52) (32131=24) (32133=52) ///
	(32201=24) (32202=33) (32203=52) (32311=24) (32312=33) (32313=52) (32314=93) (32323=83) (32331=24) (32332=33) (32333=52) (33113=95) ///
	(33114=95) (33133=95) (33203=52) (33312=95) (33313=95) (33314=95) (34113=93) (34114=93) (34121=31) (34122=31) (34123=83) (34131=31) ///
	(34201=31) (34202=31) (34203=43) (34311=31) (34312=31) (34313=51) (34314=93) (34321=31) (34322=31) (34323=83) (34324=93) (34331=31) ///
	(34332=31) (34333=83) (35111=21) (35112=35) (35113=44) (35123=83) (35131=25) (35132=35) (35133=44) (35201=21) (35202=35) (35203=44) ///
	(35311=21) (35312=35) (35313=44) (35314=44) (35322=35) (35323=83) (35332=35) (35333=44) (36111=21) (36112=31) (36113=43) (36114=93) ///
	(36202=31) (36203=43) (36311=21) (36312=31) (36313=43) (36314=93) (36323=83) (36332=31) (36333=43) (40111=22) (40112=32) (40113=53) ///
	(40131=22) (40132=32) (40201=22) (40202=32) (40203=53) (40311=22) (40312=32) (40313=53) (40314=53) (40321=22) (40322=32) (40323=32) ///
	(40331=22) (40332=32) (40333=32) (41111=23) (41112=23) (41113=23) (41132=23) (41201=23) (41202=23) (41203=53) (41311=23) (41312=23) ///
	(41313=53) (41314=53) (41323=53) (41331=23) (41332=23) (41333=53) (42111=222) (42112=333) (42113=42) (42131=222) (42201=222) (42202=333) ///
	(42203=42) (42311=222) (42312=333) (42313=42) (42331=222) (42332=333) (42333=44) (43111=222) (43112=333) (43131=222) (43132=333) (43201=222) ///
	(43311=222) (43312=333) (43313=42) (43331=222) (43332=333) (44111=21) (44112=54) (44113=75) (41122=75) (44131=21) (44132=31) (44201=21) ///
	(44202=54) (44203=75) (44311=21) (44312=54) (44313=75) (44314=96) (44322=75) (44323=75) (44331=21) (44332=31) (45111=26) (45112=26) ///
	(45122=54) (45123=75) (45131=25) (45132=35) (45201=26) (45202=26) (45203=35) (45311=26) (45312=26) (45313=35) (45322=35) (45323=35) ///
	(45331=25) (45332=35) (45333=35) (46111=26) (46112=34) (46113=34) (46201=26) (46202=34) (46203=34) (46311=26) (46312=34) (46313=34) ///
	(46314=96) (46331=26) (46332=34) (46333=34) (47112=54) (47113=54) (47131=25) (47202=33) (47203=54) (47312=33) (47313=54) (47314=96) ///
	(47322=35) (47323=54) (47331=25) (47332=35) (47333=54) (48311=33) (48312=33) (48313=54) (48322=54) (48323=54) (48331=31) (48332=33) ///
	(48333=54) (49311=01) (49312=01) (49313=02) (49314=03) (49322=01) (49323=02) (49331=01) (49332=01) (49333=02) (50111=26) (50112=34) ///
	(50113=34) (50122=35) (50131=21) (50132=35) (50201=26) (50202=34) (50311=26) (50312=34) (50313=34) (50322=35) (50331=21) (50332=35) ///
	(51112=34) (51113=96) (51202=34) (51203=34) (51312=34) (51313=51) (51314=96) (51331=21) (52112=34) (52113=34) (52122=34) (52123=34) ///
	(52133=34) (52202=34) (52203=42) (52312=34) (52313=34) (52314=96) (52322=34) (52323=34) (52332=34) (52333=34) (53111=34) (53112=34) ///
	(53113=51) (53123=51) (53202=34) (53203=51) (53312=34) (53313=51) (53314=51) (53323=51) (53333=51) (54111=24) (54112=51) (54113=51) ///
	(54131=24) (54132=51) (54133=51) (54202=51) (54311=24) (54312=51) (54313=51) (54314=96) (54331=24) (54332=51) (54333=51) (55203=51) ///
	(55313=51) (55314=91) (56113=91) (56114=91) (56123=81) (56202=51) (56203=51) (56313=91) (56314=91) (56323=81) (56324=91) (57112=51) ///
	(57113=51) (57202=51) (57203=51) (57312=51) (57313=51) (57314=51) (58112=34) (58113=51) (58123=51) (58132=34) (58202=34) (58203=51) ///
	(58312=34) (58313=51) (58314=96) (58323=51) (58332=35) (58333=51) (60111=21) (60112=31) (60113=61) (60114=92) (60122=83) (60123=83) ///
	(60131=21) (60132=31) (60201=21) (60202=31) (60203=61) (60311=21) (60312=31) (60313=61) (60314=92) (60322=31) (60323=83) (60324=92) ///
	(60331=21) (60332=31) (60333=83) (61111=22) (61112=31) (61113=61) (61123=61) (61131=21) (61133=61) (61201=22) (61202=61) (61203=61) ///
	(61311=22) (61312=31) (61313=61) (61314=92) (61323=61) (61331=21) (62111=21) (62112=31) (62113=62) (62201=21) (62202=31) (62203=62) ///
	(62311=21) (62312=31) (62313=62) (62314=92) (62322=31) (62323=83) (62332=31) (63111=21) (63112=31) (63113=61) (63123=61) (63202=31) ///
	(63203=61) (63311=21) (63312=31) (63313=61) (63314=92) (63323=83) (63331=21) (63332=31) (63333=83) (64113=62) (64202=31) (64203=62) ///
	(64311=21) (64312=31) (64313=62) (64314=92) (64323=83) (64331=21) (65112=31) (65113=62) (65313=62) (65314=62) (70111=21) (70112=31) ///
	(70122=31) (70131=21) (70132=31) (70201=21) (70202=31) (70203=81) (70311=21) (70312=31) (70313=81) (70314=93) (70322=31) (70323=81) ///
	(70324=93) (70331=21) (70332=31) (70333=81) (71113=81) (71201=21) (71202=31) (71203=31) (71311=21) (71312=31) (71313=31) (71314=93) ///
	(71322=31) (71323=31) (71324=93) (71331=21) (71332=31) (71333=31) (72111=21) (72112=31) (72113=71) (72114=93) (72122=83) (72123=83) ///
	(72131=21) (72132=31) (72133=74) (72201=21) (72202=31) (72203=71) (72311=21) (72312=31) (72313=71) (72314=93) (72322=31) (72323=83) ///
	(72331=21) (72332=31) (72333=74) (80111=21) (80112=73) (80113=75) (80123=81) (80131=21) (80132=21) (80133=81) (80201=21) (80202=31) ///
	(80203=777) (80311=21) (80312=333) (80313=777) (80314=93) (80322=31) (80323=81) (80324=93) (80331=21) (80332=31) (80333=81) (81131=25) ///
	(81132=35) (81201=25) (81202=35) (81331=25) (81332=35) (81333=41) (82111=21) (82112=74) (82113=777) (82123=75) (82131=21) (82132=31) ///
	(82133=72) (82202=31) (82203=72) (82312=74) (82313=72) (82314=93) (82323=75) (82332=31) (82333=72) (90111=21) (90112=31) (90113=72) ///
	(90201=21) (90202=31) (90203=72) (90311=21) (90312=31) (90313=72) (90314=93) (90323=72) (90331=21) (90332=31) (90333=72) (91111=21) ///
	(91131=21) (91201=21) (91202=31) (91311=21) (91312=31) (91313=31) (91331=21) (92111=21) (92112=35) (92113=72) (92131=25) (92132=35) ///
	(92201=21) (92202=31) (92203=72) (92311=21) (92312=35) (92313=72) (92314=93) (92323=72) (92331=25) (92332=35) (92333=72) (99000/max=99) ///
	(else=.), gen(ciuoa)
	*Ocupados
	destring pp11d_cod, replace force
	recode pp11d_cod (1=11) (1001=11) (2001=26) (3001=11) (4001=11) (5001=13) (5002=14) (6001=13) (6002=99) (7001=12) (10111=24) (10112=33) ///
	(10113=41) (10122=33) (10123=41) (10131=24) (10132=33) (10133=41) (10201=24) (10202=33) (10203=41) (10311=24) (10312=33) (10313=41) ///
	(10314=42) (10322=33) (10323=41) (10331=24) (10332=34) (10333=41) (11111=26) (11112=34) (11113=41) (11131=26) (11132=34) (11201=26) ///
	(11202=34) (11203=41) (11311=26) (11312=34) (11313=41) (11323=41) (11331=26) (11332=34) (11333=41) (20111=24) (20112=33) (20113=43) ///
	(20131=24) (20132=33) (20133=43) (20201=24) (20202=33) (20203=43) (20311=24) (20312=33) (20313=43) (20314=41) (20323=43) (20331=24) ///
	(20332=42) (20333=42) (30111=24) (30112=33) (30113=52) (30123=52) (30131=24) (30132=33) (30133=52) (30201=24) (30202=33) (30203=52) ///
	(30311=24) (30312=33) (30313=52) (30314=52) (30323=52) (30331=24) (30332=33) (30333=52) (31111=24) (31112=33) (31113=52) (31123=52) ///
	(31131=24) (31132=33) (31133=52) (31202=33) (31311=24) (31312=33) (31313=52) (31314=52) (31323=52) (31331=24) (31332=33) (31333=52) ///
	(32111=24) (32112=33) (32113=52) (32123=52) (32131=24) (32133=52) ///
	(32201=24) (32202=33) (32203=52) (32311=24) (32312=33) (32313=52) (32314=93) (32323=83) (32331=24) (32332=33) (32333=52) (33113=95) ///
	(33114=95) (33133=95) (33203=52) (33312=95) (33313=95) (33314=95) (34113=93) (34114=93) (34121=31) (34122=31) (34123=83) (34131=31) ///
	(34201=31) (34202=31) (34203=43) (34311=31) (34312=31) (34313=51) (34314=93) (34321=31) (34322=31) (34323=83) (34324=93) (34331=31) ///
	(34332=31) (34333=83) (35111=21) (35112=35) (35113=44) (35123=83) (35131=25) (35132=35) (35133=44) (35201=21) (35202=35) (35203=44) ///
	(35311=21) (35312=35) (35313=44) (35314=44) (35322=35) (35323=83) (35332=35) (35333=44) (36111=21) (36112=31) (36113=43) (36114=93) ///
	(36202=31) (36203=43) (36311=21) (36312=31) (36313=43) (36314=93) (36323=83) (36332=31) (36333=43) (40111=22) (40112=32) (40113=53) ///
	(40131=22) (40132=32) (40201=22) (40202=32) (40203=53) (40311=22) (40312=32) (40313=53) (40314=53) (40321=22) (40322=32) (40323=32) ///
	(40331=22) (40332=32) (40333=32) (41111=23) (41112=23) (41113=23) (41132=23) (41201=23) (41202=23) (41203=53) (41311=23) (41312=23) ///
	(41313=53) (41314=53) (41323=53) (41331=23) (41332=23) (41333=53) (42111=222) (42112=333) (42113=42) (42131=222) (42201=222) (42202=333) ///
	(42203=42) (42311=222) (42312=333) (42313=42) (42331=222) (42332=333) (42333=44) (43111=222) (43112=333) (43131=222) (43132=333) (43201=222) ///
	(43311=222) (43312=333) (43313=42) (43331=222) (43332=333) (44111=21) (44112=54) (44113=75) (41122=75) (44131=21) (44132=31) (44201=21) ///
	(44202=54) (44203=75) (44311=21) (44312=54) (44313=75) (44314=96) (44322=75) (44323=75) (44331=21) (44332=31) (45111=26) (45112=26) ///
	(45122=54) (45123=75) (45131=25) (45132=35) (45201=26) (45202=26) (45203=35) (45311=26) (45312=26) (45313=35) (45322=35) (45323=35) ///
	(45331=25) (45332=35) (45333=35) (46111=26) (46112=34) (46113=34) (46201=26) (46202=34) (46203=34) (46311=26) (46312=34) (46313=34) ///
	(46314=96) (46331=26) (46332=34) (46333=34) (47112=54) (47113=54) (47131=25) (47202=33) (47203=54) (47312=33) (47313=54) (47314=96) ///
	(47322=35) (47323=54) (47331=25) (47332=35) (47333=54) (48311=33) (48312=33) (48313=54) (48322=54) (48323=54) (48331=31) (48332=33) ///
	(48333=54) (49311=01) (49312=01) (49313=02) (49314=03) (49322=01) (49323=02) (49331=01) (49332=01) (49333=02) (50111=26) (50112=34) ///
	(50113=34) (50122=35) (50131=21) (50132=35) (50201=26) (50202=34) (50311=26) (50312=34) (50313=34) (50322=35) (50331=21) (50332=35) ///
	(51112=34) (51113=96) (51202=34) (51203=34) (51312=34) (51313=51) (51314=96) (51331=21) (52112=34) (52113=34) (52122=34) (52123=34) ///
	(52133=34) (52202=34) (52203=42) (52312=34) (52313=34) (52314=96) (52322=34) (52323=34) (52332=34) (52333=34) (53111=34) (53112=34) ///
	(53113=51) (53123=51) (53202=34) (53203=51) (53312=34) (53313=51) (53314=51) (53323=51) (53333=51) (54111=24) (54112=51) (54113=51) ///
	(54131=24) (54132=51) (54133=51) (54202=51) (54311=24) (54312=51) (54313=51) (54314=96) (54331=24) (54332=51) (54333=51) (55203=51) ///
	(55313=51) (55314=91) (56113=91) (56114=91) (56123=81) (56202=51) (56203=51) (56313=91) (56314=91) (56323=81) (56324=91) (57112=51) ///
	(57113=51) (57202=51) (57203=51) (57312=51) (57313=51) (57314=51) (58112=34) (58113=51) (58123=51) (58132=34) (58202=34) (58203=51) ///
	(58312=34) (58313=51) (58314=96) (58323=51) (58332=35) (58333=51) (60111=21) (60112=31) (60113=61) (60114=92) (60122=83) (60123=83) ///
	(60131=21) (60132=31) (60201=21) (60202=31) (60203=61) (60311=21) (60312=31) (60313=61) (60314=92) (60322=31) (60323=83) (60324=92) ///
	(60331=21) (60332=31) (60333=83) (61111=22) (61112=31) (61113=61) (61123=61) (61131=21) (61133=61) (61201=22) (61202=61) (61203=61) ///
	(61311=22) (61312=31) (61313=61) (61314=92) (61323=61) (61331=21) (62111=21) (62112=31) (62113=62) (62201=21) (62202=31) (62203=62) ///
	(62311=21) (62312=31) (62313=62) (62314=92) (62322=31) (62323=83) (62332=31) (63111=21) (63112=31) (63113=61) (63123=61) (63202=31) ///
	(63203=61) (63311=21) (63312=31) (63313=61) (63314=92) (63323=83) (63331=21) (63332=31) (63333=83) (64113=62) (64202=31) (64203=62) ///
	(64311=21) (64312=31) (64313=62) (64314=92) (64323=83) (64331=21) (65112=31) (65113=62) (65313=62) (65314=62) (70111=21) (70112=31) ///
	(70122=31) (70131=21) (70132=31) (70201=21) (70202=31) (70203=81) (70311=21) (70312=31) (70313=81) (70314=93) (70322=31) (70323=81) ///
	(70324=93) (70331=21) (70332=31) (70333=81) (71113=81) (71201=21) (71202=31) (71203=31) (71311=21) (71312=31) (71313=31) (71314=93) ///
	(71322=31) (71323=31) (71324=93) (71331=21) (71332=31) (71333=31) (72111=21) (72112=31) (72113=71) (72114=93) (72122=83) (72123=83) ///
	(72131=21) (72132=31) (72133=74) (72201=21) (72202=31) (72203=71) (72311=21) (72312=31) (72313=71) (72314=93) (72322=31) (72323=83) ///
	(72331=21) (72332=31) (72333=74) (80111=21) (80112=73) (80113=75) (80123=81) (80131=21) (80132=21) (80133=81) (80201=21) (80202=31) ///
	(80203=777) (80311=21) (80312=333) (80313=777) (80314=93) (80322=31) (80323=81) (80324=93) (80331=21) (80332=31) (80333=81) (81131=25) ///
	(81132=35) (81201=25) (81202=35) (81331=25) (81332=35) (81333=41) (82111=21) (82112=74) (82113=777) (82123=75) (82131=21) (82132=31) ///
	(82133=72) (82202=31) (82203=72) (82312=74) (82313=72) (82314=93) (82323=75) (82332=31) (82333=72) (90111=21) (90112=31) (90113=72) ///
	(90201=21) (90202=31) (90203=72) (90311=21) (90312=31) (90313=72) (90314=93) (90323=72) (90331=21) (90332=31) (90333=72) (91111=21) ///
	(91131=21) (91201=21) (91202=31) (91311=21) (91312=31) (91313=31) (91331=21) (92111=21) (92112=35) (92113=72) (92131=25) (92132=35) ///
	(92201=21) (92202=31) (92203=72) (92311=21) (92312=35) (92313=72) (92314=93) (92323=72) (92331=25) (92332=35) (92333=72) (99000/max=99) ///
	(else=.), gen(ciuob)
	
	
	destring pp11b_cod, replace force
	replace pp11b_cod = pp11b_cod * 100 if pp11b_cod < 100
	tostring pp11b_cod, replace format(%11.0f)
	gen caes_desocup=substr(pp11b_cod,1,2)
	destring caes_desocup, replace force
	lab var caes_desocup "CAES desocupados (2 dígitos)"
	
	*********Casos especiales que se clasifican con el CAES****************
	*Ocupados
	gen ciuoc =.
	replace ciuoc=21 if caes2 == 71 & ciuoa == 222
	replace ciuoc=21 if caes2 == 72 & ciuoa == 222
	replace ciuoc=22 if caes2 == 86 & ciuoa == 222
	replace ciuoc=24 if caes2 == 78 & ciuoa == 222
	replace ciuoc=24 if caes2 == 70 & ciuoa == 222
	replace ciuoc=21 if caes2 == 74 & ciuoa == 222
	replace ciuoc=31 if caes2 == 71 & ciuoa == 333
	replace ciuoc=31 if caes2 == 72 & ciuoa == 333
	replace ciuoc=32 if caes2 == 86 & ciuoa == 333
	replace ciuoc=33 if caes2 == 84 & ciuoa == 333
	replace ciuoc=31 if caes2 == 74 & ciuoa == 333
	replace ciuoc=75 if caes2 == 10 & ciuoa == 777
	replace ciuoc=75 if caes2 == 11 & ciuoa == 777 
	replace ciuoc=75 if caes2 == 12 & ciuoa == 777
	replace ciuoc=75 if caes2 == 13 & ciuoa == 777
	replace ciuoc=75 if caes2 == 14 & ciuoa == 777
	replace ciuoc=75 if caes2 == 15 & ciuoa == 777
	replace ciuoc=75 if caes2 == 16 & ciuoa == 777
	replace ciuoc=81 if caes2 == 17 & ciuoa == 777
	replace ciuoc=73 if caes2 == 18 & ciuoa == 777
	replace ciuoc=81 if caes2 == 19 & ciuoa == 777
	replace ciuoc=81 if caes2 == 20 & ciuoa == 777
	replace ciuoc=81 if caes2 == 21 & ciuoa == 777
	replace ciuoc=81 if caes2 == 22 & ciuoa == 777
	replace ciuoc=73 if caes2 == 23 & ciuoa == 777
	replace ciuoc=81 if caes2 == 24 & ciuoa == 777
	replace ciuoc=72 if caes2 == 25 & ciuoa == 777
	replace ciuoc=74 if caes2 == 26 & ciuoa == 777
	replace ciuoc=82 if caes2 == 27 & ciuoa == 777
	replace ciuoc=82 if caes2 == 28 & ciuoa == 777
	replace ciuoc=72 if caes2 == 29 & ciuoa == 777
	replace ciuoc=72 if caes2 == 30 & ciuoa == 777
	replace ciuoc=75 if caes2 == 31 & ciuoa == 777 
	replace ciuoa = 0 if ciuoa ==. | ciuoa >= 222
	replace ciuoc = 0 if ciuoc ==.
	
	*Ocupados
	gen ciuod =.
	replace ciuod=21 if caes_desocup == 71 & ciuob == 222
	replace ciuod=21 if caes_desocup == 72 & ciuob == 222
	replace ciuod=22 if caes_desocup == 86 & ciuob == 222
	replace ciuod=24 if caes_desocup == 78 & ciuob == 222
	replace ciuod=24 if caes_desocup == 70 & ciuob == 222
	replace ciuod=21 if caes_desocup == 74 & ciuob == 222
	replace ciuod=31 if caes_desocup == 71 & ciuob == 333
	replace ciuod=31 if caes_desocup == 72 & ciuob == 333
	replace ciuod=32 if caes_desocup == 86 & ciuob == 333
	replace ciuod=33 if caes_desocup == 84 & ciuob == 333
	replace ciuod=31 if caes_desocup == 74 & ciuob == 333
	replace ciuod=75 if caes_desocup == 10 & ciuob == 777
	replace ciuod=75 if caes_desocup == 11 & ciuob == 777
	replace ciuod=75 if caes_desocup == 12 & ciuob == 777
	replace ciuod=75 if caes_desocup == 13 & ciuob == 777
	replace ciuod=75 if caes_desocup == 14 & ciuob == 777
	replace ciuod=75 if caes_desocup == 15 & ciuob == 777
	replace ciuod=75 if caes_desocup == 16 & ciuob == 777
	replace ciuod=81 if caes_desocup == 17 & ciuob == 777
	replace ciuod=73 if caes_desocup == 18 & ciuob == 777
	replace ciuod=81 if caes_desocup == 19 & ciuob == 777
	replace ciuod=81 if caes_desocup == 20 & ciuob == 777
	replace ciuod=81 if caes_desocup == 21 & ciuob == 777
	replace ciuod=81 if caes_desocup == 22 & ciuob == 777
	replace ciuod=73 if caes_desocup == 23 & ciuob == 777
	replace ciuod=81 if caes_desocup == 24 & ciuob == 777
	replace ciuod=72 if caes_desocup == 25 & ciuob == 777
	replace ciuod=74 if caes_desocup == 26 & ciuob == 777
	replace ciuod=82 if caes_desocup == 27 & ciuob == 777
	replace ciuod=82 if caes_desocup == 28 & ciuob == 777
	replace ciuod=72 if caes_desocup == 29 & ciuob == 777
	replace ciuod=72 if caes_desocup == 30 & ciuob == 777
	replace ciuod=75 if caes_desocup == 31 & ciuob == 777
	replace ciuob = 0 if ciuob ==. | ciuob >= 222
	replace ciuod = 0 if ciuod ==.
	
	gen ciuo = ciuoa + ciuob + ciuoc + ciuod
	lab var ciuo "CIUO (2 dígitos)"
	**************Información parcial e insuficiente (IN- DEC)********************
	*Ocupados
	replace ciuo = 41 if pp04d_cod == 10339
	replace ciuo = 42 if pp04d_cod == 20339
	replace ciuo = 52 if pp04d_cod == 30119
	replace ciuo = 52 if pp04d_cod == 30139
	replace ciuo = 52 if pp04d_cod == 30319
	replace ciuo = 52 if pp04d_cod == 30339
	replace ciuo = 52 if pp04d_cod == 31319
	
	*Desocupados
	replace ciuo = 41 if pp11d_cod == 10339
	replace ciuo = 42 if pp11d_cod == 20339
	replace ciuo = 52 if pp11d_cod == 30119
	replace ciuo = 52 if pp11d_cod == 30139
	replace ciuo = 52 if pp11d_cod == 30319
	replace ciuo = 52 if pp11d_cod == 30339
	replace ciuo = 52 if pp11d_cod == 31319
	
	***** Casos no resueltos por INDEC (decisiones de los autores en base a las correspondencias entre el CNO y el CIUO en la EPH20152) *************
	*Ocupados
	replace ciuo = 71 if pp04d_cod ==82113 & caes2 ==40
	replace ciuo = 72 if pp04d_cod ==82113 & caes2 ==45
	replace ciuo = 75 if pp04d_cod ==82113 & caes2 ==95
	replace ciuo = 73 if pp04d_cod ==80313 & caes2 ==32
	replace ciuo = 71 if pp04d_cod ==80313 & caes2 ==40
	replace ciuo = 72 if pp04d_cod ==80313 & caes2 ==45
	replace ciuo = 75 if pp04d_cod ==80313 & caes2 ==48
	replace ciuo = 72 if pp04d_cod ==80313 & caes2 ==84
	replace ciuo = 72 if pp04d_cod ==80313 & (caes2 ==99 | caes2 == .)
	replace ciuo = 24 if pp04d_cod ==43331 & caes2 ==84
	replace ciuo = 21 if pp04d_cod ==42331 & caes2 ==84
	replace ciuo = 23 if pp04d_cod ==42331 & caes2 ==85
	replace ciuo = 21 if pp04d_cod ==42311 & caes2 ==85
	
	gen isco_eph_1d = .
		replace isco_eph_1d = 0 if ciuo>=1 & ciuo<=3
		replace isco_eph_1d = 1 if ciuo>=11 & ciuo<=14
		replace isco_eph_1d = 2 if ciuo>=21 & ciuo<=26
		replace isco_eph_1d = 3 if ciuo>=31 & ciuo<=35
		replace isco_eph_1d = 4 if ciuo>=41 & ciuo<=44
		replace isco_eph_1d = 5 if ciuo>=51 & ciuo<=54
		replace isco_eph_1d = 6 if ciuo==61 | ciuo==62
		replace isco_eph_1d = 7 if ciuo>=71 & ciuo<=75
		replace isco_eph_1d = 8 if ciuo>=81 & ciuo<=83
		replace isco_eph_1d = 9 if ciuo>=91 & ciuo<=96
		la define isco_eph_1d 0 "armed forces occupations" 1 "managers" 2 "professionals" 3 "technicians and associate professionals" 4 "clerical support workers" 5 "services and sales workers" 6 "skilled agricultural, forestry and fishing" 7 "craft and related trades workers" 8 "plant and machine operators and assemblers" 9  "elementary occupations"
		la values isco_eph_1d isco_eph_1d
		save "$data\cleaned\EPH_T`i'22.dta", replace
	
}

*Generate matrices with skill shares by occupation in Argentina and Uruguay (xls files)

run "$code\prepare_skills_map_ARG.do"
run "$code\prepare_skills_map_URY.do"

*Generate time series (job postings, employment rate and unemployment rate)

run "$code\series_ARG.do"
run "$code\series_URY.do"

*Generate COVID Stringency Index monthly series 

run "$code\gen_covid_str_index.do"

*Generate EIL vacancy series 

run "$code\gen_vacancy_series.do"