/*============================================================================
Understanding Labor Market Demand in Real Time in Argentina and Uruguay
Reproducibility package - Main results
==============================================================================*/

clear all

*Figure 1: Deployment of human capital in Argentina and Uruguay, 2020

use "$data\cleaned\uhci.dta", clear 

export excel using "$output\main\figures\figures.xlsx", sheet("fig1", modify) cell("B2")

*Table 6: Online job postings by year

use "$data\cleaned\ARG_postingsout.dta", clear

ta year, matcell(tab6_a)

use "$data\cleaned\baseUryNueva_completa.dta", clear

ta year, matcell(tab6_b)

mat tab6 = tab6_a , tab6_b 

drop _all 

svmat tab6 

export excel using "$output\main\tables\tables.xlsx", sheet("tab6", modify) cell("B3")

*Table 7: Missing values in online job postings data, 2020-23

use "$data\cleaned\ARG_postingsout.dta", clear

mat tab7_a = J(7, 1, .)

count if market_name ==	.
mat tab7_a[1, 1] = r(N)

count if company_id == .
mat tab7_a[2, 1] = r(N)

count if isco_08_1 == .
mat tab7_a[3, 1] = r(N)

count if sector_id == .
mat tab7_a[4, 1] = r(N)

count if salary_average == .
mat tab7_a[6, 1] = r(N)

count 
mat tab7_a[7, 1] = r(N)

use "$data\cleaned\postings&skillsARGout.dta", clear

summ check if check == 2
mat tab7_a[5, 1] = r(N)

use "$data\cleaned\baseUryNueva_completa.dta", clear

mat tab7_b = J(7, 1, .)

count if market_name == "" & year==2021 & month>6
*count if market_name ==	""
mat tab7_b[1, 1] = r(N)

count if employert_name == 0
mat tab7_b[2, 1] = r(N)

count if isco_08_1_name == "Unclassified ISCO"
mat tab7_b[3, 1] = r(N)

count if sector == "Unclassified"
mat tab7_b[4, 1] = r(N)

count if salary_average == .
mat tab7_b[6, 1] = r(N)

count 
mat tab7_b[7, 1] = r(N)

use "$data\cleaned\postings&skillsURYout.dta", clear

summ check if check == 1
mat tab7_b[5, 1] = r(N)

mat tab7 = tab7_a, tab7_b 

drop _all 

svmat tab7 

export excel using "$output\main\tables\tables.xlsx", sheet("tab7", modify) cell("B3")

*Figure 2: Online job postings in Argentina and Uruguay, 2020-23

use "$data\cleaned\ARG_postingsout.dta", clear

gen year_month = string(year) + "-" + string(month, "%02.0f")

ta year_month, matcell(fig2_a)

mat aux = J(4, 1, 0) /*Add empty rows*/

mat fig2_a = aux \ fig2_a

mat drop aux 

use "$data\cleaned\baseUryNueva_completa.dta", clear

gen year_month = string(year) + "-" + string(month, "%02.0f")

ta year_month, matcell(fig2_b)

mat aux = J(7, 1, 0) /*Add empty rows*/

mat fig2_b = aux \ fig2_b 

mat drop aux 

mat fig2 = fig2_a, fig2_b 

drop _all 

svmat fig2 

export excel using "$output\main\figures\figures.xlsx", sheet("fig2", modify) cell("C3")

*Figure 3: Comparing job postings and vacancies in the Argentina EIL, 2020-23

use "$data\cleaned\ARG_postingsout.dta", clear

gen year_month = string(year) + "-" + string(month, "%02.0f")

drop if inlist(year_month, "2020-05", "2023-08", "2023-09", "2023-10", "2023-11", "2023-12") 

ta year_month if duration <= 60 & sample_eil == 1, matcell(fig3_a)

use "$data\cleaned\eil_vacancies.dta", clear

drop date 

mkmat(vacancies)

mat rename vacancies fig3_b 

mat fig3 = fig3_a, fig3_b 

drop _all 

svmat fig3

export excel using "$output\main\figures\figures.xlsx", sheet("fig3", modify) cell("C2")

*Figure 4: Job postings and COVID Stringency Index in Argentina and Uruguay, 2020-22

use "$data\cleaned\covid_string_index.dta", clear 

drop year_month 

export excel using "$output\main\figures\figures.xlsx", sheet("fig4", modify) cell("C3")

*Figure 5: Job postings, employment rate, and unemployment rate in Argentina and Uruguay, 2020-23

import excel "$data\raw\cuadros_tasas_indicadores_eph_09_24.xls", sheet("Cuadro 1.1") cellrange(S7:AK9) clear

drop S T W AB AG

mkmat _all, mat(fig5_a)

mat fig5_a = fig5_a '

drop _all 

svmat fig5_a 

drop fig5_a1

replace fig5_a2 = fig5_a2/100

replace fig5_a3 = fig5_a3/100

export excel using "$output\main\figures\figures.xlsx", sheet("fig5", modify) cell("C3")

import excel "$data\raw\serie_empleo_ury.xlsx", sheet("Sheet1") cellrange(A1:D226) firstrow clear

gen index = _n 

keep if inrange(index, 176, 216)

drop Mes Actividad index

replace Empleo = Empleo/100

replace Desempleo = Desempleo/100

export excel using "$output\main\figures\figures.xlsx", sheet("fig5", modify) cell("H3")

*Figure 6: Job postings and employment by geographical areas in Argentina, 2023

import delimited "$data\raw\usu_individual_T423.txt", clear

*Generate provinces 

gen prov = .
replace prov = 	1	if inlist(aglomerado, 2, 3, 33, 34, 38) 
replace prov = 	2	if aglomerado == 22
replace prov = 	3	if aglomerado == 8
replace prov = 	4	if inlist(aglomerado, 9, 91) 
replace prov = 	5	if aglomerado == 32
replace prov = 	6	if aglomerado == 12
replace prov = 	7	if inlist(aglomerado, 13, 36)
replace prov = 	8	if inlist(aglomerado, 6, 14)
replace prov = 	9	if aglomerado == 15
replace prov = 	10	if aglomerado == 19
replace prov = 	11	if aglomerado == 30
replace prov = 	12	if aglomerado == 25
replace prov = 	13	if aglomerado == 10
replace prov = 	14	if aglomerado == 7
replace prov = 	15	if aglomerado == 17
replace prov = 	16	if aglomerado == 93
replace prov = 	17	if aglomerado == 23
replace prov = 	18	if aglomerado == 27
replace prov = 	19	if aglomerado == 26
replace prov = 	20	if aglomerado == 20
replace prov = 	21	if inrange(aglomerado, 4, 5)
replace prov = 	22	if aglomerado == 18
replace prov = 	23	if aglomerado == 31
replace prov = 	24	if aglomerado == 29

lab def prov 1 "BA" 2 "CA" 3 "CH" 4 "CT" 5 "CABA" 6 "CO" 7 "CB" 8 "ER" 9 "FO" 10 "JY" 11 "LP" 12 "LR" 13 "MZ" 14 "MI" 15 "NQ" 16 "RN" 17 "SA" 18 "SJ" 19 "SL" 20 "SC" 21 "SF" 22 "SE" 23 "TF" 24 "TU"
lab values prov prov

ta prov if estado == 1 [w= pondera], matcell(fig6_a)

use "$data\cleaned\ARG_postingsout.dta", clear

ta market_name if year == 2023 & inrange(month, 10, 12), matcell(fig6_b)

mat fig6 = fig6_a, fig6_b 

drop _all 

svmat fig6

gen aux_1 = sum(fig61)
gen aux_2 = sum(fig62)

gen share1 = fig61/aux_1[_N]
gen share2 = fig62/aux_2[_N]

drop aux*

order share1, after(fig61)

export excel using "$output\main\figures\figures.xlsx", sheet("fig6", modify) cell("C3")

*Table 8: Percentage distribution of job postings and employment by occupational group, 2020-23

use "$data\cleaned\ARG_postingsout.dta", clear

keep if date >= tm(2020m5) & date <= tm(2023m12)

ta isco_08_1, m matcell(tab8_a)

use "$data\cleaned\EPH_T322.dta", clear

append using "$data\cleaned\EPH_T422.dta"

ta isco_eph_1d if estado == 1 & isco_eph_1d > 0 [w=pondera], m matcell(tab8_b)

use "$data\cleaned\baseUryNueva_completa.dta", clear

keep if date >= tm(2020m8) & date <= tm(2023m12)

*Recode ISCO_08 

replace isco_08_1 = "" if isco_08_1 == "X"
destring isco_08_1, replace

la define isco_08_1 1 "Managers" 2 "Professionals" 3 "Technicians and associate professionals" 4 "Clerical support workers" 5 "Service and sales workers" 6 "skilled agricultural, forestry and fishing" 7 "Craft and related trades workers" 8 "plant and machine operators and assemblers" 9 "Elementary occupations"

la val isco_08_1 isco_08_1

ta isco_08_1 if isco_08_1 > 0, m matcell(tab8_c)

import delimited "$data\raw\ECH_2022.csv", clear

*Create ISCO_08 - 2 digits 

gen     isco_08_1 = .
replace isco_08_1 = 0	if  f71_2>=110 & f71_2<=310
replace isco_08_1 = 1	if  f71_2>=1111 & f71_2<=1439
replace isco_08_1 = 2	if  f71_2>=2111 & f71_2<=2836
replace isco_08_1 = 3	if  f71_2>=3111 & f71_2<=3522
replace isco_08_1 = 4	if  f71_2>=4110 & f71_2<=4419
replace isco_08_1 = 5	if  f71_2>=5111 & f71_2<=5419
replace isco_08_1 = 6	if  f71_2>=6111 & f71_2<=6224
replace isco_08_1 = 7	if  f71_2>=7111 & f71_2<=7544
replace isco_08_1 = 8	if  f71_2>=8111 & f71_2<=8350
replace isco_08_1 = 9	if  f71_2>=9111 & f71_2<=9629
replace isco_08_1 = .	if   pobpcoac!=2 

la define isco_08_1 1 "Managers" 2 "Professionals" 3 "Technicians and associate professionals" 4 "Clerical support workers" 5 "Service and sales workers" 6 "skilled agricultural, forestry and fishing" 7 "Craft and related trades workers" 8 "plant and machine operators and assemblers" 9 "Elementary occupations"

ta isco_08_1 [w=w_ano] if pobpcoac == 2 & isco_08_1 > 0, m matcell(tab8_d)

mat tab8_d = tab8_d\0

mat tab8 = tab8_a, tab8_b, tab8_c, tab8_d 

drop _all 

svmat tab8 

forvalues i=1(1)4 {
	
	gen aux_`i' = sum(tab8`i')
	gen shr_`i' = tab8`i'/aux_`i'[_N]*100
}

keep shr_* 

export excel using "$output\main\tables\tables.xlsx", sheet("tab8", modify) cell("C4")

*Table 9: Top employers by share of job postings, 2020-23

*Argentina

use "$data\cleaned\ARG_postingsout.dta", clear

keep if date >= tm(2020m5) & date <= tm(2023m12)

summ company_id

local tot_id = r(N)

by company_name_re: gen postings_firm = _N

duplicates drop company_id, force

gen share_firm = postings_firm/`tot_id'*100

keep company_name_re share_firm 

gsort -share_firm

drop if company_name_re == "" 

drop if _n > 11

export excel using "$output\main\tables\tables.xlsx", sheet("tab9", modify) cell("B3")

*Uruguay 

use "$data\cleaned\baseUryNueva_completa.dta", clear

keep if date >= tm(2020m8) & date <= tm(2023m12)

replace company_name_re = "Unclassified" if company_name == "Unclassified"

count 

local tot_p = r(N)

bysort company_name_re: gen postings_firm = _N

duplicates drop company_id, force

gen share_firm = postings_firm/`tot_p'*100

keep company_name_re share_firm 

gsort -share_firm

drop if company_name_re == "" 

drop if _n > 11

export excel using "$output\main\tables\tables.xlsx", sheet("tab9", modify) cell("E3")

*Table 10: Distribution of skills by categories in Argentina, Chile, and Uruguay

use "$data\cleaned\skills_ARG4_cat&noncat.dta", clear 

ta skill_tax if skill_tax > 0, matcell(tab10_a)

use "$data\cleaned\skills_CHL4_cat&noncat.dta", clear 

ta skill_tax if skill_tax > 0, matcell(tab10_b)

use "$data\cleaned\skills_URY4_cat&noncat.dta", clear 

ta skill_tax if skill_tax > 0, matcell(tab10_c)

mat tab10 = tab10_a, tab10_b, tab10_c

drop _all

svmat tab10 

export excel using "$output\main\tables\tables.xlsx", sheet("tab10", modify) cell("B4")

*Figure 8: Skill categories in demand in Argentina, Chile, and Uruguay, 2021-23

mat fig8 = J(5, 3, .)

*Argentina 

use "$data\cleaned\postings&skillsARGout_tax.dta", clear 

drop if skill_tax == 0

drop if check == 2

*Keep postings between January-2021 and December-2023 
keep if date >= tm(2021m1) & date <= tm(2023m12)

forvalues i = 1(1)5 {
	summ posting_tax`i'  
	mat fig8[`i', 1] = r(mean)
}

*Chile  

use "$data\cleaned\postings&skillsCHLout_tax.dta", clear 

drop if skill_tax == 0

drop if check == 2

*Keep postings between January-2021 and December-2023 
keep if date >= tm(2021m1) & date <= tm(2023m12)

forvalues i = 1(1)5 {
	summ posting_tax`i'
	mat fig8[`i', 2] = r(mean)
}

*Uruguay 

use "$data\cleaned\postings&skillsURYout_tax.dta", clear 

drop if skill_tax == 0

cap drop if check == 2 

*Keep postings between January-2021 and December-2023 
keep if date >= tm(2021m1) & date <= tm(2023m12)

forvalues i = 1(1)5 {
	summ posting_tax`i'
	mat fig8[`i', 3] = r(mean)
}

drop _all 

svmat fig8 

export excel using "$output\main\figures\figures.xlsx", sheet("fig8", modify) cell("C3")

*Figure 9: Top skills by skill category in Argentina, Chile, and Uruguay, 2021-23

mat def fig9 = J(46, 3, .)

local cnt = 1 

local ctrs "ARG CHL URY"

foreach ctr of local ctrs {

	use "$data\cleaned/postings&skills`ctr'out_tax.dta", clear 
	
	cap drop if check == 2 
	
	*Keep postings between January-2021 and December-2023 
	keep if date >= tm(2021m1) & date <= tm(2023m12)
	
	*Store mean values in matrix 
	
	summ posting_cognitive1
	mat fig9[1, `cnt'] = r(mean)
	
	summ posting_cognitive2
	mat fig9[2, `cnt'] = r(mean)
	
	summ posting_cognitive3
	mat fig9[3, `cnt'] = r(mean)
	
	summ posting_cognitive4
	mat fig9[4, `cnt'] = r(mean)
	
	summ posting_cognitive5
	mat fig9[5, `cnt'] = r(mean)
	
	summ posting_cognitive6
	mat fig9[6, `cnt'] = r(mean)
	
	summ posting_cognitive7
	mat fig9[7, `cnt'] = r(mean)
	
	summ posting_cognitive8
	mat fig9[8, `cnt'] = r(mean)
	
	summ posting_cognitive9
	mat fig9[9, `cnt'] = r(mean)
	
	summ posting_cognitive10
	mat fig9[10, `cnt'] = r(mean)
	
	summ posting_cognitive11
	mat fig9[11, `cnt'] = r(mean)
	
	summ posting_digital1
	mat fig9[12, `cnt'] = r(mean)
	
	summ posting_digital2
	mat fig9[13, `cnt'] = r(mean)
	
	summ posting_digital3
	mat fig9[14, `cnt'] = r(mean)
	
	summ posting_social1
	mat fig9[15, `cnt'] = r(mean)
	
	summ posting_social2
	mat fig9[16, `cnt'] = r(mean)
	
	summ posting_social3
	mat fig9[17, `cnt'] = r(mean)
	
	summ posting_social4
	mat fig9[18, `cnt'] = r(mean)
	
	summ posting_social5
	mat fig9[19, `cnt'] = r(mean)
	
	summ posting_social6
	mat fig9[20, `cnt'] = r(mean)
	
	summ posting_social7
	mat fig9[21, `cnt'] = r(mean)
	
	summ posting_social8
	mat fig9[22, `cnt'] = r(mean)
	
	summ posting_manual1
	mat fig9[23, `cnt'] = r(mean)
	
	summ posting_manual2
	mat fig9[24, `cnt'] = r(mean)
	
	summ posting_manual3
	mat fig9[25, `cnt'] = r(mean)
	
	summ posting_manual4
	mat fig9[26, `cnt'] = r(mean)
	
	summ posting_manual5
	mat fig9[27, `cnt'] = r(mean)
	
	summ posting_adds1
	mat fig9[28, `cnt'] = r(mean)
	
	summ posting_adds2
	mat fig9[29, `cnt'] = r(mean)
	
	summ posting_adds3
	mat fig9[30, `cnt'] = r(mean)
	
	summ posting_adds4
	mat fig9[31, `cnt'] = r(mean)
	
	summ posting_adds5
	mat fig9[32, `cnt'] = r(mean)
	
	summ posting_adds6
	mat fig9[33, `cnt'] = r(mean)
	
	summ posting_adds7
	mat fig9[34, `cnt'] = r(mean)
	
	summ posting_adds8
	mat fig9[35, `cnt'] = r(mean)
	
	summ posting_adds9
	mat fig9[36, `cnt'] = r(mean)
	
	summ posting_adds10
	mat fig9[37, `cnt'] = r(mean)
	
	summ posting_adds11
	mat fig9[38, `cnt'] = r(mean)
	
	summ posting_adds12
	mat fig9[39, `cnt'] = r(mean)
	
	summ posting_adds13
	mat fig9[40, `cnt'] = r(mean)
	
	summ posting_adds14
	mat fig9[41, `cnt'] = r(mean)
	
	summ posting_adds15
	mat fig9[42, `cnt'] = r(mean)
	
	summ posting_adds16
	mat fig9[43, `cnt'] = r(mean)
	
	summ posting_adds17
	mat fig9[44, `cnt'] = r(mean)
	
	summ posting_adds18
	mat fig9[45, `cnt'] = r(mean)
	
	summ posting_adds19
	mat fig9[46, `cnt'] = r(mean)
	
	local ++ cnt
}

drop _all 

svmat fig9 

export excel using "$output\main\figures\figures.xlsx", sheet("fig9", modify) cell("C3")

*Table 12: Correlations of skill requirements, 2020-23

local ctrs = "ARG CHL URY"

local cell = 3

foreach ctr of local ctrs {

	use "$data\cleaned/postings&skills`ctr'out_tax.dta", clear 

	cap drop if check == 2 
	
	* only postings
	keep if num_posting==1
	* excluding job postings with missing firm identifiers
	drop if missing(company_id)
	* count postings by firm
	bysort company_id: egen post_count = total(num_posting)
	* keep firms with at least 10 postings
	drop if post_count < 10

	pwcorr posting_cognitive_tot posting_digital_tot posting_social_tot posting_manual_tot posting_tech_tot 
	
	mat tab12 = r(C)
	
	drop _all 
	
	svmat tab12
	
	export excel using "$output\main\tables\tables.xlsx", sheet("tab12", modify) cell("C`cell'")
	
	local cell = `cell' + 8

}

*Figure 10: Top skills requested for the four most in-demand occupations in Argentina, Chile, and Uruguay with the United States as a Comparator, 2021-23

mat def fig10 = J(20, 3, .)

use "$data\cleaned\postings&skillsARGout_tax.dta", clear 

drop if check == 2 

*Argentina - Software developers 

sum posting_digital3 if num_postings==1 & isco_08_4 == "2512"
mat fig10[1, 1] = r(mean)

sum posting_digital2 if num_postings==1 & isco_08_4 == "2512"
mat fig10[2, 1] = r(mean)

sum posting_social4 if num_postings==1 & isco_08_4 == "2512"
mat fig10[3, 1] = r(mean)

sum posting_cognitive10 if num_postings==1 & isco_08_4 == "2512"
mat fig10[4, 1] = r(mean)

sum posting_cognitive1 if num_postings==1 & isco_08_4 == "2512"
mat fig10[5, 1] = r(mean)

*Argentina - Management and organization analysts  
sum posting_digital2 if num_postings==1 & isco_08_4 == "2421"
mat fig10[6, 1] = r(mean)

sum posting_social4 if num_postings==1 & isco_08_4 == "2421"
mat fig10[7, 1] = r(mean)

sum posting_social6 if num_postings==1 & isco_08_4 == "2421"
mat fig10[8, 1] = r(mean)

sum posting_cognitive7 if num_postings==1 & isco_08_4 == "2421"
mat fig10[9, 1] = r(mean)

sum posting_social2  if num_postings==1 & isco_08_4 == "2421"
mat fig10[10, 1] = r(mean)

*Argentina - Commercial Sales Representatives  
sum posting_social6 if num_postings==1 & isco_08_4 == "3322"
mat fig10[11, 1] = r(mean)

sum posting_social2 if num_postings==1 & isco_08_4 == "3322"
mat fig10[12, 1] = r(mean)

sum posting_social4 if num_postings==1 & isco_08_4 == "3322"
mat fig10[13, 1] = r(mean)

sum posting_cognitive7  if num_postings==1 & isco_08_4 == "3322"
mat fig10[14, 1] = r(mean)

sum posting_digital2  if num_postings==1 & isco_08_4 == "3322"
mat fig10[15, 1] = r(mean)

*Argentina -  Administrative and Executive Secretary  
sum posting_social4 if num_postings==1 & isco_08_4 == "3343"
mat fig10[16, 1] = r(mean)

sum posting_cognitive4 if num_postings==1 & isco_08_4 == "3343"
mat fig10[17, 1] = r(mean)

sum posting_digital1 if num_postings==1 & isco_08_4 == "3343"
mat fig10[18, 1] = r(mean)

sum posting_social6 if num_postings==1 & isco_08_4 == "3343"
mat fig10[19, 1] = r(mean)

sum posting_social2 if num_postings==1 & isco_08_4 == "3343"
mat fig10[20, 1] = r(mean)

use "$data\cleaned\postings&skillsCHLout_tax.dta", clear 

cap drop if check == 2 

*Chile - Software developers 
sum posting_social6 if num_postings==1 & isco_08_4 == "3343"
mat fig10[1, 2] = r(mean)

sum posting_digital1 if num_postings==1 & isco_08_4 == "3343"
mat fig10[2, 2] = r(mean)

sum posting_social4 if num_postings==1 & isco_08_4 == "3343"
mat fig10[3, 2] = r(mean)

sum posting_cognitive7 if num_postings==1 & isco_08_4 == "3343"
mat fig10[4, 2] = r(mean)

sum posting_cognitive8 if num_postings==1 & isco_08_4 == "3343"
mat fig10[5, 2] = r(mean)

*Chile - Shop sales assistants 
sum posting_social6 if num_postings==1 & isco_08_4 == "5223"
mat fig10[6, 2] = r(mean)

sum posting_cognitive8 if num_postings==1 & isco_08_4 == "5223"
mat fig10[7, 2] = r(mean)

sum posting_digital1 if num_postings==1 & isco_08_4 == "5223"
mat fig10[8, 2] = r(mean)

sum posting_manual2 if num_postings==1 & isco_08_4 == "5223"
mat fig10[9, 2] = r(mean)

sum posting_social4 if num_postings==1 & isco_08_4 == "5223"
mat fig10[10, 2] = r(mean)

*Chile - Shop sales assistants 
sum posting_social6 if num_postings==1 & isco_08_4 == "3322"
mat fig10[11, 2] = r(mean)

sum posting_digital1 if num_postings==1 & isco_08_4 == "3322"
mat fig10[12, 2] = r(mean)

sum posting_cognitive8 if num_postings==1 & isco_08_4 == "3322"
mat fig10[13, 2] = r(mean)

sum posting_digital2  if num_postings==1 & isco_08_4 == "3322"
mat fig10[14, 2] = r(mean)

sum posting_cognitive7 if num_postings==1 & isco_08_4 == "3322"
mat fig10[15, 2] = r(mean)

*Chile - Contact centre information clerks
sum posting_social6 if num_postings==1 & isco_08_4 == "4222"
mat fig10[16, 2] = r(mean)

sum posting_digital1 if num_postings==1 & isco_08_4 == "4222"
mat fig10[17, 2] = r(mean)

sum posting_cognitive8 if num_postings==1 & isco_08_4 == "4222"
mat fig10[18, 2] = r(mean)

sum posting_digital2 if num_postings==1 & isco_08_4 == "4222"
mat fig10[19, 2] = r(mean)

sum posting_social4 if num_postings==1 & isco_08_4 == "4222"
mat fig10[20, 2] = r(mean)

use "$data\cleaned\postings&skillsURYout_tax.dta", clear 

cap drop if check == 2 

*Uruguay - Administrative and Executive Secretary  

sum posting_social4 if num_postings==1 & isco_08_4 == "3343"
mat fig10[1, 3] = r(mean)

sum posting_digital1 if num_postings==1 & isco_08_4 == "3343"
mat fig10[2, 3] = r(mean)

sum posting_cognitive4 if num_postings==1 & isco_08_4 == "3343"
mat fig10[3, 3] = r(mean)

sum posting_social2 if num_postings==1 & isco_08_4 == "3343"
mat fig10[4, 3] = r(mean)

sum posting_social6 if num_postings==1 & isco_08_4 == "3343"
mat fig10[5, 3] = r(mean)

*Uruguay - Software developers 

sum posting_digital3 if num_postings==1 & isco_08_4 == "2512"
mat fig10[6, 3] = r(mean)

sum posting_digital2 if num_postings==1 & isco_08_4 == "2512"
mat fig10[7, 3] = r(mean)

sum posting_cognitive10 if num_postings==1 & isco_08_4 == "2512"
mat fig10[8, 3] = r(mean)

sum posting_social4 if num_postings==1 & isco_08_4 == "2512"
mat fig10[9, 3] = r(mean)

sum posting_cognitive1 if num_postings==1 & isco_08_4 == "2512"
mat fig10[10, 3] = r(mean)

*Uruguay -  Shop sales assistants 
sum posting_social6 if num_postings==1 & isco_08_4 == "5223"
mat fig10[11, 3] = r(mean)

sum posting_social4 if num_postings==1 & isco_08_4 == "5223"
mat fig10[12, 3] = r(mean)

sum posting_social2 if num_postings==1 & isco_08_4 == "5223"
mat fig10[13, 3] = r(mean)

sum posting_digital1 if num_postings==1 & isco_08_4 == "5223"
mat fig10[14, 3] = r(mean)

sum posting_digital2 if num_postings==1 & isco_08_4 == "5223"
mat fig10[15, 3] = r(mean)

*Uruguay - Contact centre information clerks  
sum posting_social6 if num_postings==1 & isco_08_4 == "4222"
mat fig10[16, 3] = r(mean)

sum posting_social2 if num_postings==1 & isco_08_4 == "4222"
mat fig10[17, 3] = r(mean)

sum posting_social4 if num_postings==1 & isco_08_4 == "4222"
mat fig10[18, 3] = r(mean)

sum posting_cognitive10 if num_postings==1 & isco_08_4 == "4222"
mat fig10[19, 3] = r(mean)

sum posting_digital1 if num_postings==1 & isco_08_4 == "4222"
mat fig10[20, 3] = r(mean)

use "$data\cleaned\postings&skillsUSout_tax.dta", clear 

cap drop _merge 

cap drop if _merge == 2

mat fig10_a = J(25, 1, .)

*US - Shop sales assistants 
sum posting_social6 if num_postings==1 & isco_08_4 == "5223"
mat fig10_a[1, 1] = r(mean)

sum posting_social2 if num_postings==1 & isco_08_4 == "5223"
mat fig10_a[2, 1] = r(mean)

sum posting_social3 if num_postings==1 & isco_08_4 == "5223"
mat fig10_a[3, 1] = r(mean)

sum posting_manual2 if num_postings==1 & isco_08_4 == "5223"
mat fig10_a[4, 1] = r(mean)

sum posting_social4 if num_postings==1 & isco_08_4 == "5223"
mat fig10_a[5, 1] = r(mean)

*US - Commercial Sales Representatives
sum posting_social6  if num_postings==1 & isco_08_4 == "3322"
mat fig10_a[6, 1] = r(mean)

sum posting_social2 if num_postings==1 & isco_08_4 == "3322"
mat fig10_a[7, 1] = r(mean)

sum posting_cognitive7 if num_postings==1 & isco_08_4 == "3322"
mat fig10_a[8, 1] = r(mean)

sum posting_social3 if num_postings==1 & isco_08_4 == "3322"
mat fig10_a[9, 1] = r(mean)

sum posting_social4 if num_postings==1 & isco_08_4 == "3322"
mat fig10_a[10, 1] = r(mean)

*US - Administrative and Executive Secretary

sum posting_social4 if num_postings==1 & isco_08_4 == "3343"
mat fig10_a[11, 1] = r(mean)

sum posting_social2 if num_postings==1 & isco_08_4 == "3343"
mat fig10_a[12, 1] = r(mean)

sum posting_social3 if num_postings==1 & isco_08_4 == "3343"
mat fig10_a[13, 1] = r(mean)

sum posting_digital1 if num_postings==1 & isco_08_4 == "3343"
mat fig10_a[14, 1] = r(mean)

sum posting_social6 if num_postings==1 & isco_08_4 == "3343"
mat fig10_a[15, 1] = r(mean)

*US - Software developers 

sum posting_digital3 if num_postings==1 & isco_08_4 == "2512"
mat fig10_a[16, 1] = r(mean)

sum posting_digital2 if num_postings==1 & isco_08_4 == "2512"
mat fig10_a[17, 1] = r(mean)

sum posting_social4 if num_postings==1 & isco_08_4 == "2512"
mat fig10_a[18, 1] = r(mean)

sum posting_cognitive1 if num_postings==1 & isco_08_4 == "2512"
mat fig10_a[19, 1] = r(mean)

sum posting_social2 if num_postings==1 & isco_08_4 == "2512"
mat fig10_a[20, 1] = r(mean)

*US -  Contact centre information clerks

sum posting_social6 if num_postings==1 & isco_08_4 == "4222"
mat fig10_a[21, 1] = r(mean)

sum posting_social2 if num_postings==1 & isco_08_4 == "4222"
mat fig10_a[22, 1] = r(mean)

sum posting_social3 if num_postings==1 & isco_08_4 == "4222"
mat fig10_a[23, 1] = r(mean)

sum posting_social4 if num_postings==1 & isco_08_4 == "4222"
mat fig10_a[24, 1] = r(mean)

sum posting_cognitive4 if num_postings==1 & isco_08_4 == "4222"
mat fig10_a[25, 1] = r(mean)

drop _all 

svmat fig10 

svmat fig10_a

export excel using "$output\main\figures\figures.xlsx", sheet("fig10", modify) cell("B3")