/*===================================================
Generation of time series - Argentina 
Output: seriesMC_ARG.dta 
=====================================================*/

*Import employment and unemployment rate series 

import excel "$data\raw\cuadros_tasas_indicadores_eph_09_24.xls", sheet("Cuadro 1.1") cellrange(S7:AK9) clear

drop W AB AG

mkmat _all, mat(ARG_series)

mat ARG_series = ARG_series '

drop _all 

svmat ARG_series 

drop ARG_series1 

rename (ARG_series2 ARG_series3) (te td)

*Generate variable to identify quarter 

gen q = tq(2020q1) + _n - 1  

format q %tq 

order q, first

*Save in temporary file 

tempfile ARG_series 

save `ARG_series'

*Import job postings database 

use "$data\cleaned\ARG_postingsout.dta", clear 

*Collapse job postings by date 

gen llamados = 1 

collapse (sum) llamados, by(date)

*Add missing months  

insobs 4, before(1)

replace date = tm(2020m1) + _n -1

format date %tm 

*Generate variable to identify quarter

gen q = qofd(dofm(date))

format q %tq

*Merge with employment and unemployment series 

merge m:1 q using `ARG_series'

drop _merge q 

*Set data as monthly time series 

tsset date

*Generate normalized series (May 2020 = 1) 

local series "llamados td te"

foreach s of local series {
	
	gen i_`s' = `s'/`s'[5]

}

*Generate series in logs  

local series "i_llamados i_td i_te"

foreach s of local series {
	
	gen ln_`s' = ln(`s')

}

*Generate series in first differences 

local series "td te"

foreach s of local series {
	
	gen d_`s' = d.`s'

}
  
*Generate series in first differences (logs)
 
 local series "ln_i_llamados ln_i_td ln_i_te"

foreach s of local series {
	
	gen d`s' = d.`s'

}

*Generate second-order moving average of postings series (logs)

tssmooth ma maln_illamados = ln_i_llamados, window(2 1)

*Generate first difference of moving average of postings series 

gen dln_maillamados = d.maln_illamados

save "$data\cleaned\seriesMC_ARG.dta", replace
