/*===================================================
Generation of time series - Uruguay 
Output: seriesMC_URY.dta 
=====================================================*/

*Import employment and unemployment rate series 

import excel "$data\raw\serie_empleo_ury.xlsx", sheet("Sheet1") cellrange(A1:D226) firstrow clear

gen date = tm(2006m1) + _n - 1

format date %tm

keep if date >= tm(2020m8) & date <= tm(2023m12) 

rename (Empleo Desempleo) (te td) 

drop Mes Actividad  

order date, first

*Save in temporary file 

tempfile URY_series 

save `URY_series'

*Import job postings database 

use "$data\cleaned\baseUryNueva_completa.dta", clear 

*Collapse job postings by date - Total 

preserve 

gen llamados = 1 

collapse (sum) llamados, by(date)

mkmat llamados, mat(total)

restore 

*Collapse job postings by date - Montevideo  

gen mont = (market_name == "Montevideo (URY)")

preserve 

gen llamados = 1 

collapse (sum) llamados if mont == 1, by(date) 

mkmat llamados, mat(mont)

restore 

*Collapse job postings by date - Rest of Uruguay   

preserve 

gen llamados = 1 

collapse (sum) llamados if mont == 0, by(date) 

mkmat llamados, mat(int)

restore 

mat URY = total, mont, int

drop _all 

svmat URY

rename (URY1 URY2 URY3) (llamados llamados_Mont llamados_int)

gen date = tm(2020m8) + _n - 1

format date %tm

order date, first

*Merge with employment and unemployment series 

merge 1:1 date using `URY_series'
 
drop _merge  

*Set data as monthly time series 

tsset date

*Generate normalized series (August 2020 = 1) 

local series "llamados td te"

foreach s of local series {
	
	gen i_`s' = `s'/`s'[1]

}

*Generate series in logs  

local series "i_llamados i_td i_te"

foreach s of local series {
	
	gen ln_`s' = ln(`s')

}

*Generate series in first differences 

local series "td te"

foreach s of local series {
	
	gen d_`s' = d.`s'

}
  
*Generate series in first differences (logs)
 
 local series "ln_i_llamados ln_i_td ln_i_te"

foreach s of local series {
	
	gen d`s' = d.`s'

}

*Generate second-order moving average of postings series (logs)

tssmooth ma maln_illamados = ln_i_llamados, window(2 1)

*Generate first difference of moving average of postings series 

gen dln_maillamados = d.maln_illamados

save "$data\cleaned\seriesMC_URY.dta", replace
