/*======================================================================================
Code to create monthly series of OXFORD COVID Stringency Index for Argentina and Uruguay
August 2020 to December 2022
=======================================================================================*/

*Import raw data 

import delimited "$data\raw\OxCGRT_compact_national_v1.csv", clear

*Keep observations corresponding to Argentina and Uruguay 

keep if countrycode == "ARG" | countrycode == "URY"

*Keep COVID Stringency Index 

keep countrycode date stringencyindex_average

*Generate monthly series 

gen year = floor(date / 10000)

gen month = floor(mod(date, 10000) / 100)

gen monthly_date = ym(year, month)

format monthly_date %tm

bysort countrycode monthly_date: egen csi = mean(stringencyindex_average)

keep if monthly_date >= tm(2020m8) & monthly_date <= tm(2022m12)

duplicates drop countrycode monthly_date, force

format monthly_date %tmMon-YY

rename monthly_date year_month 

gen aux_arg = csi if countrycode == "ARG"
 
gen aux_ury = csi if countrycode == "URY"

bysort year_month: egen csi_arg = mean(aux_arg)
bysort year_month: egen csi_ury = mean(aux_ury)

keep year_month csi_arg csi_ury 

duplicates drop year_month, force 

*Export cleaned data 

save "$data\cleaned\covid_string_index.dta"